from google.ads.google_ads.v1.proto.common.ad_asset_pb2 import AdImageAsset as AdImageAsset
from google.ads.google_ads.v1.proto.common.ad_asset_pb2 import AdMediaBundleAsset as AdMediaBundleAsset
from google.ads.google_ads.v1.proto.common.ad_asset_pb2 import AdTextAsset as AdTextAsset
from google.ads.google_ads.v1.proto.common.ad_asset_pb2 import AdVideoAsset as AdVideoAsset
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import AppAdInfo as AppAdInfo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import AppEngagementAdInfo as AppEngagementAdInfo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import CallOnlyAdInfo as CallOnlyAdInfo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import DisplayCallToAction as DisplayCallToAction
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import DisplayUploadAdInfo as DisplayUploadAdInfo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import ExpandedDynamicSearchAdInfo as ExpandedDynamicSearchAdInfo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import ExpandedTextAdInfo as ExpandedTextAdInfo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import GmailAdInfo as GmailAdInfo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import GmailTeaser as GmailTeaser
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import HotelAdInfo as HotelAdInfo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import ImageAdInfo as ImageAdInfo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import LegacyAppInstallAdInfo as LegacyAppInstallAdInfo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import LegacyResponsiveDisplayAdInfo as LegacyResponsiveDisplayAdInfo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import ProductImage as ProductImage
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import ProductVideo as ProductVideo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import ResponsiveDisplayAdInfo as ResponsiveDisplayAdInfo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import ResponsiveSearchAdInfo as ResponsiveSearchAdInfo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import ShoppingComparisonListingAdInfo as ShoppingComparisonListingAdInfo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import ShoppingProductAdInfo as ShoppingProductAdInfo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import ShoppingSmartAdInfo as ShoppingSmartAdInfo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import TextAdInfo as TextAdInfo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import VideoAdInfo as VideoAdInfo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import VideoBumperInStreamAdInfo as VideoBumperInStreamAdInfo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import VideoNonSkippableInStreamAdInfo as VideoNonSkippableInStreamAdInfo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import VideoOutstreamAdInfo as VideoOutstreamAdInfo
from google.ads.google_ads.v1.proto.common.ad_type_infos_pb2 import VideoTrueViewInStreamAdInfo as VideoTrueViewInStreamAdInfo
from google.ads.google_ads.v1.proto.common.asset_types_pb2 import ImageAsset as ImageAsset
from google.ads.google_ads.v1.proto.common.asset_types_pb2 import ImageDimension as ImageDimension
from google.ads.google_ads.v1.proto.common.asset_types_pb2 import MediaBundleAsset as MediaBundleAsset
from google.ads.google_ads.v1.proto.common.asset_types_pb2 import TextAsset as TextAsset
from google.ads.google_ads.v1.proto.common.asset_types_pb2 import YoutubeVideoAsset as YoutubeVideoAsset
from google.ads.google_ads.v1.proto.common.bidding_pb2 import Commission as Commission
from google.ads.google_ads.v1.proto.common.bidding_pb2 import EnhancedCpc as EnhancedCpc
from google.ads.google_ads.v1.proto.common.bidding_pb2 import ManualCpc as ManualCpc
from google.ads.google_ads.v1.proto.common.bidding_pb2 import ManualCpm as ManualCpm
from google.ads.google_ads.v1.proto.common.bidding_pb2 import ManualCpv as ManualCpv
from google.ads.google_ads.v1.proto.common.bidding_pb2 import MaximizeConversionValue as MaximizeConversionValue
from google.ads.google_ads.v1.proto.common.bidding_pb2 import MaximizeConversions as MaximizeConversions
from google.ads.google_ads.v1.proto.common.bidding_pb2 import PageOnePromoted as PageOnePromoted
from google.ads.google_ads.v1.proto.common.bidding_pb2 import PercentCpc as PercentCpc
from google.ads.google_ads.v1.proto.common.bidding_pb2 import TargetCpa as TargetCpa
from google.ads.google_ads.v1.proto.common.bidding_pb2 import TargetCpm as TargetCpm
from google.ads.google_ads.v1.proto.common.bidding_pb2 import TargetImpressionShare as TargetImpressionShare
from google.ads.google_ads.v1.proto.common.bidding_pb2 import TargetOutrankShare as TargetOutrankShare
from google.ads.google_ads.v1.proto.common.bidding_pb2 import TargetRoas as TargetRoas
from google.ads.google_ads.v1.proto.common.bidding_pb2 import TargetSpend as TargetSpend
from google.ads.google_ads.v1.proto.common.click_location_pb2 import ClickLocation as ClickLocation
from google.ads.google_ads.v1.proto.common.criteria_pb2 import AdScheduleInfo as AdScheduleInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import AddressInfo as AddressInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import AgeRangeInfo as AgeRangeInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import AppPaymentModelInfo as AppPaymentModelInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import CarrierInfo as CarrierInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import ContentLabelInfo as ContentLabelInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import CustomAffinityInfo as CustomAffinityInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import CustomIntentInfo as CustomIntentInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import DeviceInfo as DeviceInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import GenderInfo as GenderInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import GeoPointInfo as GeoPointInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import HotelAdvanceBookingWindowInfo as HotelAdvanceBookingWindowInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import HotelCheckInDayInfo as HotelCheckInDayInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import HotelCityInfo as HotelCityInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import HotelClassInfo as HotelClassInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import HotelCountryRegionInfo as HotelCountryRegionInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import HotelDateSelectionTypeInfo as HotelDateSelectionTypeInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import HotelIdInfo as HotelIdInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import HotelLengthOfStayInfo as HotelLengthOfStayInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import HotelStateInfo as HotelStateInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import IncomeRangeInfo as IncomeRangeInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import InteractionTypeInfo as InteractionTypeInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import IpBlockInfo as IpBlockInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import KeywordInfo as KeywordInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import LanguageInfo as LanguageInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import ListingBrandInfo as ListingBrandInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import ListingCustomAttributeInfo as ListingCustomAttributeInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import ListingDimensionInfo as ListingDimensionInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import ListingGroupInfo as ListingGroupInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import ListingScopeInfo as ListingScopeInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import LocationGroupInfo as LocationGroupInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import LocationInfo as LocationInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import MobileAppCategoryInfo as MobileAppCategoryInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import MobileApplicationInfo as MobileApplicationInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import MobileDeviceInfo as MobileDeviceInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import OperatingSystemVersionInfo as OperatingSystemVersionInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import ParentalStatusInfo as ParentalStatusInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import PlacementInfo as PlacementInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import PreferredContentInfo as PreferredContentInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import ProductBiddingCategoryInfo as ProductBiddingCategoryInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import ProductChannelExclusivityInfo as ProductChannelExclusivityInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import ProductChannelInfo as ProductChannelInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import ProductConditionInfo as ProductConditionInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import ProductItemIdInfo as ProductItemIdInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import ProductTypeInfo as ProductTypeInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import ProximityInfo as ProximityInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import TopicInfo as TopicInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import UnknownListingDimensionInfo as UnknownListingDimensionInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import UserInterestInfo as UserInterestInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import UserListInfo as UserListInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import WebpageConditionInfo as WebpageConditionInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import WebpageInfo as WebpageInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import YouTubeChannelInfo as YouTubeChannelInfo
from google.ads.google_ads.v1.proto.common.criteria_pb2 import YouTubeVideoInfo as YouTubeVideoInfo
from google.ads.google_ads.v1.proto.common.criterion_category_availability_pb2 import CriterionCategoryAvailability as CriterionCategoryAvailability
from google.ads.google_ads.v1.proto.common.criterion_category_availability_pb2 import CriterionCategoryChannelAvailability as CriterionCategoryChannelAvailability
from google.ads.google_ads.v1.proto.common.criterion_category_availability_pb2 import CriterionCategoryLocaleAvailability as CriterionCategoryLocaleAvailability
from google.ads.google_ads.v1.proto.common.custom_parameter_pb2 import CustomParameter as CustomParameter
from google.ads.google_ads.v1.proto.common.dates_pb2 import DateRange as DateRange
from google.ads.google_ads.v1.proto.common.explorer_auto_optimizer_setting_pb2 import ExplorerAutoOptimizerSetting as ExplorerAutoOptimizerSetting
from google.ads.google_ads.v1.proto.common.extensions_pb2 import AffiliateLocationFeedItem as AffiliateLocationFeedItem
from google.ads.google_ads.v1.proto.common.extensions_pb2 import AppFeedItem as AppFeedItem
from google.ads.google_ads.v1.proto.common.extensions_pb2 import CallFeedItem as CallFeedItem
from google.ads.google_ads.v1.proto.common.extensions_pb2 import CalloutFeedItem as CalloutFeedItem
from google.ads.google_ads.v1.proto.common.extensions_pb2 import LocationFeedItem as LocationFeedItem
from google.ads.google_ads.v1.proto.common.extensions_pb2 import PriceFeedItem as PriceFeedItem
from google.ads.google_ads.v1.proto.common.extensions_pb2 import PriceOffer as PriceOffer
from google.ads.google_ads.v1.proto.common.extensions_pb2 import PromotionFeedItem as PromotionFeedItem
from google.ads.google_ads.v1.proto.common.extensions_pb2 import SitelinkFeedItem as SitelinkFeedItem
from google.ads.google_ads.v1.proto.common.extensions_pb2 import StructuredSnippetFeedItem as StructuredSnippetFeedItem
from google.ads.google_ads.v1.proto.common.extensions_pb2 import TextMessageFeedItem as TextMessageFeedItem
from google.ads.google_ads.v1.proto.common.feed_common_pb2 import Money as Money
from google.ads.google_ads.v1.proto.common.final_app_url_pb2 import FinalAppUrl as FinalAppUrl
from google.ads.google_ads.v1.proto.common.frequency_cap_pb2 import FrequencyCapEntry as FrequencyCapEntry
from google.ads.google_ads.v1.proto.common.frequency_cap_pb2 import FrequencyCapKey as FrequencyCapKey
from google.ads.google_ads.v1.proto.common.keyword_plan_common_pb2 import KeywordPlanHistoricalMetrics as KeywordPlanHistoricalMetrics
from google.ads.google_ads.v1.proto.common.matching_function_pb2 import MatchingFunction as MatchingFunction
from google.ads.google_ads.v1.proto.common.matching_function_pb2 import Operand as Operand
from google.ads.google_ads.v1.proto.common.metrics_pb2 import Metrics as Metrics
from google.ads.google_ads.v1.proto.common.policy_pb2 import PolicyTopicConstraint as PolicyTopicConstraint
from google.ads.google_ads.v1.proto.common.policy_pb2 import PolicyTopicEntry as PolicyTopicEntry
from google.ads.google_ads.v1.proto.common.policy_pb2 import PolicyTopicEvidence as PolicyTopicEvidence
from google.ads.google_ads.v1.proto.common.policy_pb2 import PolicyValidationParameter as PolicyValidationParameter
from google.ads.google_ads.v1.proto.common.policy_pb2 import PolicyViolationKey as PolicyViolationKey
from google.ads.google_ads.v1.proto.common.real_time_bidding_setting_pb2 import RealTimeBiddingSetting as RealTimeBiddingSetting
from google.ads.google_ads.v1.proto.common.segments_pb2 import Keyword as Keyword
from google.ads.google_ads.v1.proto.common.segments_pb2 import Segments as Segments
from google.ads.google_ads.v1.proto.common.simulation_pb2 import BidModifierSimulationPoint as BidModifierSimulationPoint
from google.ads.google_ads.v1.proto.common.simulation_pb2 import BidModifierSimulationPointList as BidModifierSimulationPointList
from google.ads.google_ads.v1.proto.common.simulation_pb2 import CpcBidSimulationPoint as CpcBidSimulationPoint
from google.ads.google_ads.v1.proto.common.simulation_pb2 import CpcBidSimulationPointList as CpcBidSimulationPointList
from google.ads.google_ads.v1.proto.common.simulation_pb2 import CpvBidSimulationPoint as CpvBidSimulationPoint
from google.ads.google_ads.v1.proto.common.simulation_pb2 import CpvBidSimulationPointList as CpvBidSimulationPointList
from google.ads.google_ads.v1.proto.common.simulation_pb2 import TargetCpaSimulationPoint as TargetCpaSimulationPoint
from google.ads.google_ads.v1.proto.common.simulation_pb2 import TargetCpaSimulationPointList as TargetCpaSimulationPointList
from google.ads.google_ads.v1.proto.common.tag_snippet_pb2 import TagSnippet as TagSnippet
from google.ads.google_ads.v1.proto.common.targeting_setting_pb2 import TargetRestriction as TargetRestriction
from google.ads.google_ads.v1.proto.common.targeting_setting_pb2 import TargetingSetting as TargetingSetting
from google.ads.google_ads.v1.proto.common.text_label_pb2 import TextLabel as TextLabel
from google.ads.google_ads.v1.proto.common.url_collection_pb2 import UrlCollection as UrlCollection
from google.ads.google_ads.v1.proto.common.user_lists_pb2 import BasicUserListInfo as BasicUserListInfo
from google.ads.google_ads.v1.proto.common.user_lists_pb2 import CombinedRuleUserListInfo as CombinedRuleUserListInfo
from google.ads.google_ads.v1.proto.common.user_lists_pb2 import CrmBasedUserListInfo as CrmBasedUserListInfo
from google.ads.google_ads.v1.proto.common.user_lists_pb2 import DateSpecificRuleUserListInfo as DateSpecificRuleUserListInfo
from google.ads.google_ads.v1.proto.common.user_lists_pb2 import ExpressionRuleUserListInfo as ExpressionRuleUserListInfo
from google.ads.google_ads.v1.proto.common.user_lists_pb2 import LogicalUserListInfo as LogicalUserListInfo
from google.ads.google_ads.v1.proto.common.user_lists_pb2 import LogicalUserListOperandInfo as LogicalUserListOperandInfo
from google.ads.google_ads.v1.proto.common.user_lists_pb2 import RuleBasedUserListInfo as RuleBasedUserListInfo
from google.ads.google_ads.v1.proto.common.user_lists_pb2 import SimilarUserListInfo as SimilarUserListInfo
from google.ads.google_ads.v1.proto.common.user_lists_pb2 import UserListActionInfo as UserListActionInfo
from google.ads.google_ads.v1.proto.common.user_lists_pb2 import UserListDateRuleItemInfo as UserListDateRuleItemInfo
from google.ads.google_ads.v1.proto.common.user_lists_pb2 import UserListLogicalRuleInfo as UserListLogicalRuleInfo
from google.ads.google_ads.v1.proto.common.user_lists_pb2 import UserListNumberRuleItemInfo as UserListNumberRuleItemInfo
from google.ads.google_ads.v1.proto.common.user_lists_pb2 import UserListRuleInfo as UserListRuleInfo
from google.ads.google_ads.v1.proto.common.user_lists_pb2 import UserListRuleItemGroupInfo as UserListRuleItemGroupInfo
from google.ads.google_ads.v1.proto.common.user_lists_pb2 import UserListRuleItemInfo as UserListRuleItemInfo
from google.ads.google_ads.v1.proto.common.user_lists_pb2 import UserListStringRuleItemInfo as UserListStringRuleItemInfo
from google.ads.google_ads.v1.proto.common.value_pb2 import Value as Value
from google.ads.google_ads.v1.proto.enums.access_reason_pb2 import AccessReasonEnum as AccessReasonEnum
from google.ads.google_ads.v1.proto.enums.account_budget_proposal_status_pb2 import AccountBudgetProposalStatusEnum as AccountBudgetProposalStatusEnum
from google.ads.google_ads.v1.proto.enums.account_budget_proposal_type_pb2 import AccountBudgetProposalTypeEnum as AccountBudgetProposalTypeEnum
from google.ads.google_ads.v1.proto.enums.account_budget_status_pb2 import AccountBudgetStatusEnum as AccountBudgetStatusEnum
from google.ads.google_ads.v1.proto.enums.ad_customizer_placeholder_field_pb2 import AdCustomizerPlaceholderFieldEnum as AdCustomizerPlaceholderFieldEnum
from google.ads.google_ads.v1.proto.enums.ad_group_ad_rotation_mode_pb2 import AdGroupAdRotationModeEnum as AdGroupAdRotationModeEnum
from google.ads.google_ads.v1.proto.enums.ad_group_ad_status_pb2 import AdGroupAdStatusEnum as AdGroupAdStatusEnum
from google.ads.google_ads.v1.proto.enums.ad_group_criterion_approval_status_pb2 import AdGroupCriterionApprovalStatusEnum as AdGroupCriterionApprovalStatusEnum
from google.ads.google_ads.v1.proto.enums.ad_group_criterion_status_pb2 import AdGroupCriterionStatusEnum as AdGroupCriterionStatusEnum
from google.ads.google_ads.v1.proto.enums.ad_group_status_pb2 import AdGroupStatusEnum as AdGroupStatusEnum
from google.ads.google_ads.v1.proto.enums.ad_group_type_pb2 import AdGroupTypeEnum as AdGroupTypeEnum
from google.ads.google_ads.v1.proto.enums.ad_network_type_pb2 import AdNetworkTypeEnum as AdNetworkTypeEnum
from google.ads.google_ads.v1.proto.enums.ad_serving_optimization_status_pb2 import AdServingOptimizationStatusEnum as AdServingOptimizationStatusEnum
from google.ads.google_ads.v1.proto.enums.ad_strength_pb2 import AdStrengthEnum as AdStrengthEnum
from google.ads.google_ads.v1.proto.enums.ad_type_pb2 import AdTypeEnum as AdTypeEnum
from google.ads.google_ads.v1.proto.enums.advertising_channel_sub_type_pb2 import AdvertisingChannelSubTypeEnum as AdvertisingChannelSubTypeEnum
from google.ads.google_ads.v1.proto.enums.advertising_channel_type_pb2 import AdvertisingChannelTypeEnum as AdvertisingChannelTypeEnum
from google.ads.google_ads.v1.proto.enums.affiliate_location_feed_relationship_type_pb2 import AffiliateLocationFeedRelationshipTypeEnum as AffiliateLocationFeedRelationshipTypeEnum
from google.ads.google_ads.v1.proto.enums.affiliate_location_placeholder_field_pb2 import AffiliateLocationPlaceholderFieldEnum as AffiliateLocationPlaceholderFieldEnum
from google.ads.google_ads.v1.proto.enums.age_range_type_pb2 import AgeRangeTypeEnum as AgeRangeTypeEnum
from google.ads.google_ads.v1.proto.enums.app_campaign_app_store_pb2 import AppCampaignAppStoreEnum as AppCampaignAppStoreEnum
from google.ads.google_ads.v1.proto.enums.app_campaign_bidding_strategy_goal_type_pb2 import AppCampaignBiddingStrategyGoalTypeEnum as AppCampaignBiddingStrategyGoalTypeEnum
from google.ads.google_ads.v1.proto.enums.app_payment_model_type_pb2 import AppPaymentModelTypeEnum as AppPaymentModelTypeEnum
from google.ads.google_ads.v1.proto.enums.app_placeholder_field_pb2 import AppPlaceholderFieldEnum as AppPlaceholderFieldEnum
from google.ads.google_ads.v1.proto.enums.app_store_pb2 import AppStoreEnum as AppStoreEnum
from google.ads.google_ads.v1.proto.enums.app_url_operating_system_type_pb2 import AppUrlOperatingSystemTypeEnum as AppUrlOperatingSystemTypeEnum
from google.ads.google_ads.v1.proto.enums.asset_type_pb2 import AssetTypeEnum as AssetTypeEnum
from google.ads.google_ads.v1.proto.enums.attribution_model_pb2 import AttributionModelEnum as AttributionModelEnum
from google.ads.google_ads.v1.proto.enums.bid_modifier_source_pb2 import BidModifierSourceEnum as BidModifierSourceEnum
from google.ads.google_ads.v1.proto.enums.bidding_source_pb2 import BiddingSourceEnum as BiddingSourceEnum
from google.ads.google_ads.v1.proto.enums.bidding_strategy_status_pb2 import BiddingStrategyStatusEnum as BiddingStrategyStatusEnum
from google.ads.google_ads.v1.proto.enums.bidding_strategy_type_pb2 import BiddingStrategyTypeEnum as BiddingStrategyTypeEnum
from google.ads.google_ads.v1.proto.enums.billing_setup_status_pb2 import BillingSetupStatusEnum as BillingSetupStatusEnum
from google.ads.google_ads.v1.proto.enums.brand_safety_suitability_pb2 import BrandSafetySuitabilityEnum as BrandSafetySuitabilityEnum
from google.ads.google_ads.v1.proto.enums.budget_delivery_method_pb2 import BudgetDeliveryMethodEnum as BudgetDeliveryMethodEnum
from google.ads.google_ads.v1.proto.enums.budget_period_pb2 import BudgetPeriodEnum as BudgetPeriodEnum
from google.ads.google_ads.v1.proto.enums.budget_status_pb2 import BudgetStatusEnum as BudgetStatusEnum
from google.ads.google_ads.v1.proto.enums.budget_type_pb2 import BudgetTypeEnum as BudgetTypeEnum
from google.ads.google_ads.v1.proto.enums.call_conversion_reporting_state_pb2 import CallConversionReportingStateEnum as CallConversionReportingStateEnum
from google.ads.google_ads.v1.proto.enums.call_placeholder_field_pb2 import CallPlaceholderFieldEnum as CallPlaceholderFieldEnum
from google.ads.google_ads.v1.proto.enums.callout_placeholder_field_pb2 import CalloutPlaceholderFieldEnum as CalloutPlaceholderFieldEnum
from google.ads.google_ads.v1.proto.enums.campaign_criterion_status_pb2 import CampaignCriterionStatusEnum as CampaignCriterionStatusEnum
from google.ads.google_ads.v1.proto.enums.campaign_draft_status_pb2 import CampaignDraftStatusEnum as CampaignDraftStatusEnum
from google.ads.google_ads.v1.proto.enums.campaign_experiment_status_pb2 import CampaignExperimentStatusEnum as CampaignExperimentStatusEnum
from google.ads.google_ads.v1.proto.enums.campaign_experiment_traffic_split_type_pb2 import CampaignExperimentTrafficSplitTypeEnum as CampaignExperimentTrafficSplitTypeEnum
from google.ads.google_ads.v1.proto.enums.campaign_experiment_type_pb2 import CampaignExperimentTypeEnum as CampaignExperimentTypeEnum
from google.ads.google_ads.v1.proto.enums.campaign_serving_status_pb2 import CampaignServingStatusEnum as CampaignServingStatusEnum
from google.ads.google_ads.v1.proto.enums.campaign_shared_set_status_pb2 import CampaignSharedSetStatusEnum as CampaignSharedSetStatusEnum
from google.ads.google_ads.v1.proto.enums.campaign_status_pb2 import CampaignStatusEnum as CampaignStatusEnum
from google.ads.google_ads.v1.proto.enums.change_status_operation_pb2 import ChangeStatusOperationEnum as ChangeStatusOperationEnum
from google.ads.google_ads.v1.proto.enums.change_status_resource_type_pb2 import ChangeStatusResourceTypeEnum as ChangeStatusResourceTypeEnum
from google.ads.google_ads.v1.proto.enums.click_type_pb2 import ClickTypeEnum as ClickTypeEnum
from google.ads.google_ads.v1.proto.enums.content_label_type_pb2 import ContentLabelTypeEnum as ContentLabelTypeEnum
from google.ads.google_ads.v1.proto.enums.conversion_action_category_pb2 import ConversionActionCategoryEnum as ConversionActionCategoryEnum
from google.ads.google_ads.v1.proto.enums.conversion_action_counting_type_pb2 import ConversionActionCountingTypeEnum as ConversionActionCountingTypeEnum
from google.ads.google_ads.v1.proto.enums.conversion_action_status_pb2 import ConversionActionStatusEnum as ConversionActionStatusEnum
from google.ads.google_ads.v1.proto.enums.conversion_action_type_pb2 import ConversionActionTypeEnum as ConversionActionTypeEnum
from google.ads.google_ads.v1.proto.enums.conversion_adjustment_type_pb2 import ConversionAdjustmentTypeEnum as ConversionAdjustmentTypeEnum
from google.ads.google_ads.v1.proto.enums.conversion_attribution_event_type_pb2 import ConversionAttributionEventTypeEnum as ConversionAttributionEventTypeEnum
from google.ads.google_ads.v1.proto.enums.conversion_lag_bucket_pb2 import ConversionLagBucketEnum as ConversionLagBucketEnum
from google.ads.google_ads.v1.proto.enums.conversion_or_adjustment_lag_bucket_pb2 import ConversionOrAdjustmentLagBucketEnum as ConversionOrAdjustmentLagBucketEnum
from google.ads.google_ads.v1.proto.enums.criterion_category_channel_availability_mode_pb2 import CriterionCategoryChannelAvailabilityModeEnum as CriterionCategoryChannelAvailabilityModeEnum
from google.ads.google_ads.v1.proto.enums.criterion_category_locale_availability_mode_pb2 import CriterionCategoryLocaleAvailabilityModeEnum as CriterionCategoryLocaleAvailabilityModeEnum
from google.ads.google_ads.v1.proto.enums.criterion_system_serving_status_pb2 import CriterionSystemServingStatusEnum as CriterionSystemServingStatusEnum
from google.ads.google_ads.v1.proto.enums.criterion_type_pb2 import CriterionTypeEnum as CriterionTypeEnum
from google.ads.google_ads.v1.proto.enums.custom_interest_member_type_pb2 import CustomInterestMemberTypeEnum as CustomInterestMemberTypeEnum
from google.ads.google_ads.v1.proto.enums.custom_interest_status_pb2 import CustomInterestStatusEnum as CustomInterestStatusEnum
from google.ads.google_ads.v1.proto.enums.custom_interest_type_pb2 import CustomInterestTypeEnum as CustomInterestTypeEnum
from google.ads.google_ads.v1.proto.enums.custom_placeholder_field_pb2 import CustomPlaceholderFieldEnum as CustomPlaceholderFieldEnum
from google.ads.google_ads.v1.proto.enums.customer_match_upload_key_type_pb2 import CustomerMatchUploadKeyTypeEnum as CustomerMatchUploadKeyTypeEnum
from google.ads.google_ads.v1.proto.enums.customer_pay_per_conversion_eligibility_failure_reason_pb2 import CustomerPayPerConversionEligibilityFailureReasonEnum as CustomerPayPerConversionEligibilityFailureReasonEnum
from google.ads.google_ads.v1.proto.enums.data_driven_model_status_pb2 import DataDrivenModelStatusEnum as DataDrivenModelStatusEnum
from google.ads.google_ads.v1.proto.enums.day_of_week_pb2 import DayOfWeekEnum as DayOfWeekEnum
from google.ads.google_ads.v1.proto.enums.device_pb2 import DeviceEnum as DeviceEnum
from google.ads.google_ads.v1.proto.enums.display_ad_format_setting_pb2 import DisplayAdFormatSettingEnum as DisplayAdFormatSettingEnum
from google.ads.google_ads.v1.proto.enums.display_upload_product_type_pb2 import DisplayUploadProductTypeEnum as DisplayUploadProductTypeEnum
from google.ads.google_ads.v1.proto.enums.dsa_page_feed_criterion_field_pb2 import DsaPageFeedCriterionFieldEnum as DsaPageFeedCriterionFieldEnum
from google.ads.google_ads.v1.proto.enums.education_placeholder_field_pb2 import EducationPlaceholderFieldEnum as EducationPlaceholderFieldEnum
from google.ads.google_ads.v1.proto.enums.extension_setting_device_pb2 import ExtensionSettingDeviceEnum as ExtensionSettingDeviceEnum
from google.ads.google_ads.v1.proto.enums.extension_type_pb2 import ExtensionTypeEnum as ExtensionTypeEnum
from google.ads.google_ads.v1.proto.enums.external_conversion_source_pb2 import ExternalConversionSourceEnum as ExternalConversionSourceEnum
from google.ads.google_ads.v1.proto.enums.feed_attribute_type_pb2 import FeedAttributeTypeEnum as FeedAttributeTypeEnum
from google.ads.google_ads.v1.proto.enums.feed_item_quality_approval_status_pb2 import FeedItemQualityApprovalStatusEnum as FeedItemQualityApprovalStatusEnum
from google.ads.google_ads.v1.proto.enums.feed_item_quality_disapproval_reason_pb2 import FeedItemQualityDisapprovalReasonEnum as FeedItemQualityDisapprovalReasonEnum
from google.ads.google_ads.v1.proto.enums.feed_item_status_pb2 import FeedItemStatusEnum as FeedItemStatusEnum
from google.ads.google_ads.v1.proto.enums.feed_item_target_device_pb2 import FeedItemTargetDeviceEnum as FeedItemTargetDeviceEnum
from google.ads.google_ads.v1.proto.enums.feed_item_target_type_pb2 import FeedItemTargetTypeEnum as FeedItemTargetTypeEnum
from google.ads.google_ads.v1.proto.enums.feed_item_validation_status_pb2 import FeedItemValidationStatusEnum as FeedItemValidationStatusEnum
from google.ads.google_ads.v1.proto.enums.feed_link_status_pb2 import FeedLinkStatusEnum as FeedLinkStatusEnum
from google.ads.google_ads.v1.proto.enums.feed_mapping_criterion_type_pb2 import FeedMappingCriterionTypeEnum as FeedMappingCriterionTypeEnum
from google.ads.google_ads.v1.proto.enums.feed_mapping_status_pb2 import FeedMappingStatusEnum as FeedMappingStatusEnum
from google.ads.google_ads.v1.proto.enums.feed_origin_pb2 import FeedOriginEnum as FeedOriginEnum
from google.ads.google_ads.v1.proto.enums.feed_status_pb2 import FeedStatusEnum as FeedStatusEnum
from google.ads.google_ads.v1.proto.enums.flight_placeholder_field_pb2 import FlightPlaceholderFieldEnum as FlightPlaceholderFieldEnum
from google.ads.google_ads.v1.proto.enums.frequency_cap_event_type_pb2 import FrequencyCapEventTypeEnum as FrequencyCapEventTypeEnum
from google.ads.google_ads.v1.proto.enums.frequency_cap_level_pb2 import FrequencyCapLevelEnum as FrequencyCapLevelEnum
from google.ads.google_ads.v1.proto.enums.frequency_cap_time_unit_pb2 import FrequencyCapTimeUnitEnum as FrequencyCapTimeUnitEnum
from google.ads.google_ads.v1.proto.enums.gender_type_pb2 import GenderTypeEnum as GenderTypeEnum
from google.ads.google_ads.v1.proto.enums.geo_target_constant_status_pb2 import GeoTargetConstantStatusEnum as GeoTargetConstantStatusEnum
from google.ads.google_ads.v1.proto.enums.geo_targeting_restriction_pb2 import GeoTargetingRestrictionEnum as GeoTargetingRestrictionEnum
from google.ads.google_ads.v1.proto.enums.geo_targeting_type_pb2 import GeoTargetingTypeEnum as GeoTargetingTypeEnum
from google.ads.google_ads.v1.proto.enums.google_ads_field_category_pb2 import GoogleAdsFieldCategoryEnum as GoogleAdsFieldCategoryEnum
from google.ads.google_ads.v1.proto.enums.google_ads_field_data_type_pb2 import GoogleAdsFieldDataTypeEnum as GoogleAdsFieldDataTypeEnum
from google.ads.google_ads.v1.proto.enums.hotel_date_selection_type_pb2 import HotelDateSelectionTypeEnum as HotelDateSelectionTypeEnum
from google.ads.google_ads.v1.proto.enums.hotel_placeholder_field_pb2 import HotelPlaceholderFieldEnum as HotelPlaceholderFieldEnum
from google.ads.google_ads.v1.proto.enums.hotel_rate_type_pb2 import HotelRateTypeEnum as HotelRateTypeEnum
from google.ads.google_ads.v1.proto.enums.income_range_type_pb2 import IncomeRangeTypeEnum as IncomeRangeTypeEnum
from google.ads.google_ads.v1.proto.enums.interaction_event_type_pb2 import InteractionEventTypeEnum as InteractionEventTypeEnum
from google.ads.google_ads.v1.proto.enums.interaction_type_pb2 import InteractionTypeEnum as InteractionTypeEnum
from google.ads.google_ads.v1.proto.enums.job_placeholder_field_pb2 import JobPlaceholderFieldEnum as JobPlaceholderFieldEnum
from google.ads.google_ads.v1.proto.enums.keyword_match_type_pb2 import KeywordMatchTypeEnum as KeywordMatchTypeEnum
from google.ads.google_ads.v1.proto.enums.keyword_plan_competition_level_pb2 import KeywordPlanCompetitionLevelEnum as KeywordPlanCompetitionLevelEnum
from google.ads.google_ads.v1.proto.enums.keyword_plan_forecast_interval_pb2 import KeywordPlanForecastIntervalEnum as KeywordPlanForecastIntervalEnum
from google.ads.google_ads.v1.proto.enums.keyword_plan_network_pb2 import KeywordPlanNetworkEnum as KeywordPlanNetworkEnum
from google.ads.google_ads.v1.proto.enums.label_status_pb2 import LabelStatusEnum as LabelStatusEnum
from google.ads.google_ads.v1.proto.enums.legacy_app_install_ad_app_store_pb2 import LegacyAppInstallAdAppStoreEnum as LegacyAppInstallAdAppStoreEnum
from google.ads.google_ads.v1.proto.enums.listing_custom_attribute_index_pb2 import ListingCustomAttributeIndexEnum as ListingCustomAttributeIndexEnum
from google.ads.google_ads.v1.proto.enums.listing_group_type_pb2 import ListingGroupTypeEnum as ListingGroupTypeEnum
from google.ads.google_ads.v1.proto.enums.local_placeholder_field_pb2 import LocalPlaceholderFieldEnum as LocalPlaceholderFieldEnum
from google.ads.google_ads.v1.proto.enums.location_extension_targeting_criterion_field_pb2 import LocationExtensionTargetingCriterionFieldEnum as LocationExtensionTargetingCriterionFieldEnum
from google.ads.google_ads.v1.proto.enums.location_group_radius_units_pb2 import LocationGroupRadiusUnitsEnum as LocationGroupRadiusUnitsEnum
from google.ads.google_ads.v1.proto.enums.location_placeholder_field_pb2 import LocationPlaceholderFieldEnum as LocationPlaceholderFieldEnum
from google.ads.google_ads.v1.proto.enums.manager_link_status_pb2 import ManagerLinkStatusEnum as ManagerLinkStatusEnum
from google.ads.google_ads.v1.proto.enums.matching_function_context_type_pb2 import MatchingFunctionContextTypeEnum as MatchingFunctionContextTypeEnum
from google.ads.google_ads.v1.proto.enums.matching_function_operator_pb2 import MatchingFunctionOperatorEnum as MatchingFunctionOperatorEnum
from google.ads.google_ads.v1.proto.enums.media_type_pb2 import MediaTypeEnum as MediaTypeEnum
from google.ads.google_ads.v1.proto.enums.merchant_center_link_status_pb2 import MerchantCenterLinkStatusEnum as MerchantCenterLinkStatusEnum
from google.ads.google_ads.v1.proto.enums.message_placeholder_field_pb2 import MessagePlaceholderFieldEnum as MessagePlaceholderFieldEnum
from google.ads.google_ads.v1.proto.enums.mime_type_pb2 import MimeTypeEnum as MimeTypeEnum
from google.ads.google_ads.v1.proto.enums.minute_of_hour_pb2 import MinuteOfHourEnum as MinuteOfHourEnum
from google.ads.google_ads.v1.proto.enums.mobile_device_type_pb2 import MobileDeviceTypeEnum as MobileDeviceTypeEnum
from google.ads.google_ads.v1.proto.enums.month_of_year_pb2 import MonthOfYearEnum as MonthOfYearEnum
from google.ads.google_ads.v1.proto.enums.mutate_job_status_pb2 import MutateJobStatusEnum as MutateJobStatusEnum
from google.ads.google_ads.v1.proto.enums.negative_geo_target_type_pb2 import NegativeGeoTargetTypeEnum as NegativeGeoTargetTypeEnum
from google.ads.google_ads.v1.proto.enums.operating_system_version_operator_type_pb2 import OperatingSystemVersionOperatorTypeEnum as OperatingSystemVersionOperatorTypeEnum
from google.ads.google_ads.v1.proto.enums.page_one_promoted_strategy_goal_pb2 import PageOnePromotedStrategyGoalEnum as PageOnePromotedStrategyGoalEnum
from google.ads.google_ads.v1.proto.enums.parental_status_type_pb2 import ParentalStatusTypeEnum as ParentalStatusTypeEnum
from google.ads.google_ads.v1.proto.enums.payment_mode_pb2 import PaymentModeEnum as PaymentModeEnum
from google.ads.google_ads.v1.proto.enums.placeholder_type_pb2 import PlaceholderTypeEnum as PlaceholderTypeEnum
from google.ads.google_ads.v1.proto.enums.placement_type_pb2 import PlacementTypeEnum as PlacementTypeEnum
from google.ads.google_ads.v1.proto.enums.policy_approval_status_pb2 import PolicyApprovalStatusEnum as PolicyApprovalStatusEnum
from google.ads.google_ads.v1.proto.enums.policy_review_status_pb2 import PolicyReviewStatusEnum as PolicyReviewStatusEnum
from google.ads.google_ads.v1.proto.enums.policy_topic_entry_type_pb2 import PolicyTopicEntryTypeEnum as PolicyTopicEntryTypeEnum
from google.ads.google_ads.v1.proto.enums.policy_topic_evidence_destination_mismatch_url_type_pb2 import PolicyTopicEvidenceDestinationMismatchUrlTypeEnum as PolicyTopicEvidenceDestinationMismatchUrlTypeEnum
from google.ads.google_ads.v1.proto.enums.policy_topic_evidence_destination_not_working_device_pb2 import PolicyTopicEvidenceDestinationNotWorkingDeviceEnum as PolicyTopicEvidenceDestinationNotWorkingDeviceEnum
from google.ads.google_ads.v1.proto.enums.positive_geo_target_type_pb2 import PositiveGeoTargetTypeEnum as PositiveGeoTargetTypeEnum
from google.ads.google_ads.v1.proto.enums.preferred_content_type_pb2 import PreferredContentTypeEnum as PreferredContentTypeEnum
from google.ads.google_ads.v1.proto.enums.price_extension_price_qualifier_pb2 import PriceExtensionPriceQualifierEnum as PriceExtensionPriceQualifierEnum
from google.ads.google_ads.v1.proto.enums.price_extension_price_unit_pb2 import PriceExtensionPriceUnitEnum as PriceExtensionPriceUnitEnum
from google.ads.google_ads.v1.proto.enums.price_extension_type_pb2 import PriceExtensionTypeEnum as PriceExtensionTypeEnum
from google.ads.google_ads.v1.proto.enums.price_placeholder_field_pb2 import PricePlaceholderFieldEnum as PricePlaceholderFieldEnum
from google.ads.google_ads.v1.proto.enums.product_bidding_category_level_pb2 import ProductBiddingCategoryLevelEnum as ProductBiddingCategoryLevelEnum
from google.ads.google_ads.v1.proto.enums.product_bidding_category_status_pb2 import ProductBiddingCategoryStatusEnum as ProductBiddingCategoryStatusEnum
from google.ads.google_ads.v1.proto.enums.product_channel_exclusivity_pb2 import ProductChannelExclusivityEnum as ProductChannelExclusivityEnum
from google.ads.google_ads.v1.proto.enums.product_channel_pb2 import ProductChannelEnum as ProductChannelEnum
from google.ads.google_ads.v1.proto.enums.product_condition_pb2 import ProductConditionEnum as ProductConditionEnum
from google.ads.google_ads.v1.proto.enums.product_type_level_pb2 import ProductTypeLevelEnum as ProductTypeLevelEnum
from google.ads.google_ads.v1.proto.enums.promotion_extension_discount_modifier_pb2 import PromotionExtensionDiscountModifierEnum as PromotionExtensionDiscountModifierEnum
from google.ads.google_ads.v1.proto.enums.promotion_extension_occasion_pb2 import PromotionExtensionOccasionEnum as PromotionExtensionOccasionEnum
from google.ads.google_ads.v1.proto.enums.promotion_placeholder_field_pb2 import PromotionPlaceholderFieldEnum as PromotionPlaceholderFieldEnum
from google.ads.google_ads.v1.proto.enums.proximity_radius_units_pb2 import ProximityRadiusUnitsEnum as ProximityRadiusUnitsEnum
from google.ads.google_ads.v1.proto.enums.quality_score_bucket_pb2 import QualityScoreBucketEnum as QualityScoreBucketEnum
from google.ads.google_ads.v1.proto.enums.real_estate_placeholder_field_pb2 import RealEstatePlaceholderFieldEnum as RealEstatePlaceholderFieldEnum
from google.ads.google_ads.v1.proto.enums.recommendation_type_pb2 import RecommendationTypeEnum as RecommendationTypeEnum
from google.ads.google_ads.v1.proto.enums.search_engine_results_page_type_pb2 import SearchEngineResultsPageTypeEnum as SearchEngineResultsPageTypeEnum
from google.ads.google_ads.v1.proto.enums.search_term_match_type_pb2 import SearchTermMatchTypeEnum as SearchTermMatchTypeEnum
from google.ads.google_ads.v1.proto.enums.search_term_targeting_status_pb2 import SearchTermTargetingStatusEnum as SearchTermTargetingStatusEnum
from google.ads.google_ads.v1.proto.enums.served_asset_field_type_pb2 import ServedAssetFieldTypeEnum as ServedAssetFieldTypeEnum
from google.ads.google_ads.v1.proto.enums.shared_set_status_pb2 import SharedSetStatusEnum as SharedSetStatusEnum
from google.ads.google_ads.v1.proto.enums.shared_set_type_pb2 import SharedSetTypeEnum as SharedSetTypeEnum
from google.ads.google_ads.v1.proto.enums.simulation_modification_method_pb2 import SimulationModificationMethodEnum as SimulationModificationMethodEnum
from google.ads.google_ads.v1.proto.enums.simulation_type_pb2 import SimulationTypeEnum as SimulationTypeEnum
from google.ads.google_ads.v1.proto.enums.sitelink_placeholder_field_pb2 import SitelinkPlaceholderFieldEnum as SitelinkPlaceholderFieldEnum
from google.ads.google_ads.v1.proto.enums.slot_pb2 import SlotEnum as SlotEnum
from google.ads.google_ads.v1.proto.enums.spending_limit_type_pb2 import SpendingLimitTypeEnum as SpendingLimitTypeEnum
from google.ads.google_ads.v1.proto.enums.structured_snippet_placeholder_field_pb2 import StructuredSnippetPlaceholderFieldEnum as StructuredSnippetPlaceholderFieldEnum
from google.ads.google_ads.v1.proto.enums.system_managed_entity_source_pb2 import SystemManagedResourceSourceEnum as SystemManagedResourceSourceEnum
from google.ads.google_ads.v1.proto.enums.target_cpa_opt_in_recommendation_goal_pb2 import TargetCpaOptInRecommendationGoalEnum as TargetCpaOptInRecommendationGoalEnum
from google.ads.google_ads.v1.proto.enums.target_impression_share_location_pb2 import TargetImpressionShareLocationEnum as TargetImpressionShareLocationEnum
from google.ads.google_ads.v1.proto.enums.targeting_dimension_pb2 import TargetingDimensionEnum as TargetingDimensionEnum
from google.ads.google_ads.v1.proto.enums.time_type_pb2 import TimeTypeEnum as TimeTypeEnum
from google.ads.google_ads.v1.proto.enums.tracking_code_page_format_pb2 import TrackingCodePageFormatEnum as TrackingCodePageFormatEnum
from google.ads.google_ads.v1.proto.enums.tracking_code_type_pb2 import TrackingCodeTypeEnum as TrackingCodeTypeEnum
from google.ads.google_ads.v1.proto.enums.travel_placeholder_field_pb2 import TravelPlaceholderFieldEnum as TravelPlaceholderFieldEnum
from google.ads.google_ads.v1.proto.enums.user_interest_taxonomy_type_pb2 import UserInterestTaxonomyTypeEnum as UserInterestTaxonomyTypeEnum
from google.ads.google_ads.v1.proto.enums.user_list_access_status_pb2 import UserListAccessStatusEnum as UserListAccessStatusEnum
from google.ads.google_ads.v1.proto.enums.user_list_closing_reason_pb2 import UserListClosingReasonEnum as UserListClosingReasonEnum
from google.ads.google_ads.v1.proto.enums.user_list_combined_rule_operator_pb2 import UserListCombinedRuleOperatorEnum as UserListCombinedRuleOperatorEnum
from google.ads.google_ads.v1.proto.enums.user_list_crm_data_source_type_pb2 import UserListCrmDataSourceTypeEnum as UserListCrmDataSourceTypeEnum
from google.ads.google_ads.v1.proto.enums.user_list_date_rule_item_operator_pb2 import UserListDateRuleItemOperatorEnum as UserListDateRuleItemOperatorEnum
from google.ads.google_ads.v1.proto.enums.user_list_logical_rule_operator_pb2 import UserListLogicalRuleOperatorEnum as UserListLogicalRuleOperatorEnum
from google.ads.google_ads.v1.proto.enums.user_list_membership_status_pb2 import UserListMembershipStatusEnum as UserListMembershipStatusEnum
from google.ads.google_ads.v1.proto.enums.user_list_number_rule_item_operator_pb2 import UserListNumberRuleItemOperatorEnum as UserListNumberRuleItemOperatorEnum
from google.ads.google_ads.v1.proto.enums.user_list_prepopulation_status_pb2 import UserListPrepopulationStatusEnum as UserListPrepopulationStatusEnum
from google.ads.google_ads.v1.proto.enums.user_list_rule_type_pb2 import UserListRuleTypeEnum as UserListRuleTypeEnum
from google.ads.google_ads.v1.proto.enums.user_list_size_range_pb2 import UserListSizeRangeEnum as UserListSizeRangeEnum
from google.ads.google_ads.v1.proto.enums.user_list_string_rule_item_operator_pb2 import UserListStringRuleItemOperatorEnum as UserListStringRuleItemOperatorEnum
from google.ads.google_ads.v1.proto.enums.user_list_type_pb2 import UserListTypeEnum as UserListTypeEnum
from google.ads.google_ads.v1.proto.enums.vanity_pharma_display_url_mode_pb2 import VanityPharmaDisplayUrlModeEnum as VanityPharmaDisplayUrlModeEnum
from google.ads.google_ads.v1.proto.enums.vanity_pharma_text_pb2 import VanityPharmaTextEnum as VanityPharmaTextEnum
from google.ads.google_ads.v1.proto.enums.webpage_condition_operand_pb2 import WebpageConditionOperandEnum as WebpageConditionOperandEnum
from google.ads.google_ads.v1.proto.enums.webpage_condition_operator_pb2 import WebpageConditionOperatorEnum as WebpageConditionOperatorEnum
from google.ads.google_ads.v1.proto.errors.account_budget_proposal_error_pb2 import AccountBudgetProposalErrorEnum as AccountBudgetProposalErrorEnum
from google.ads.google_ads.v1.proto.errors.ad_customizer_error_pb2 import AdCustomizerErrorEnum as AdCustomizerErrorEnum
from google.ads.google_ads.v1.proto.errors.ad_error_pb2 import AdErrorEnum as AdErrorEnum
from google.ads.google_ads.v1.proto.errors.ad_group_ad_error_pb2 import AdGroupAdErrorEnum as AdGroupAdErrorEnum
from google.ads.google_ads.v1.proto.errors.ad_group_bid_modifier_error_pb2 import AdGroupBidModifierErrorEnum as AdGroupBidModifierErrorEnum
from google.ads.google_ads.v1.proto.errors.ad_group_criterion_error_pb2 import AdGroupCriterionErrorEnum as AdGroupCriterionErrorEnum
from google.ads.google_ads.v1.proto.errors.ad_group_error_pb2 import AdGroupErrorEnum as AdGroupErrorEnum
from google.ads.google_ads.v1.proto.errors.ad_group_feed_error_pb2 import AdGroupFeedErrorEnum as AdGroupFeedErrorEnum
from google.ads.google_ads.v1.proto.errors.ad_parameter_error_pb2 import AdParameterErrorEnum as AdParameterErrorEnum
from google.ads.google_ads.v1.proto.errors.ad_sharing_error_pb2 import AdSharingErrorEnum as AdSharingErrorEnum
from google.ads.google_ads.v1.proto.errors.adx_error_pb2 import AdxErrorEnum as AdxErrorEnum
from google.ads.google_ads.v1.proto.errors.asset_error_pb2 import AssetErrorEnum as AssetErrorEnum
from google.ads.google_ads.v1.proto.errors.authentication_error_pb2 import AuthenticationErrorEnum as AuthenticationErrorEnum
from google.ads.google_ads.v1.proto.errors.authorization_error_pb2 import AuthorizationErrorEnum as AuthorizationErrorEnum
from google.ads.google_ads.v1.proto.errors.bidding_error_pb2 import BiddingErrorEnum as BiddingErrorEnum
from google.ads.google_ads.v1.proto.errors.bidding_strategy_error_pb2 import BiddingStrategyErrorEnum as BiddingStrategyErrorEnum
from google.ads.google_ads.v1.proto.errors.billing_setup_error_pb2 import BillingSetupErrorEnum as BillingSetupErrorEnum
from google.ads.google_ads.v1.proto.errors.campaign_budget_error_pb2 import CampaignBudgetErrorEnum as CampaignBudgetErrorEnum
from google.ads.google_ads.v1.proto.errors.campaign_criterion_error_pb2 import CampaignCriterionErrorEnum as CampaignCriterionErrorEnum
from google.ads.google_ads.v1.proto.errors.campaign_draft_error_pb2 import CampaignDraftErrorEnum as CampaignDraftErrorEnum
from google.ads.google_ads.v1.proto.errors.campaign_error_pb2 import CampaignErrorEnum as CampaignErrorEnum
from google.ads.google_ads.v1.proto.errors.campaign_experiment_error_pb2 import CampaignExperimentErrorEnum as CampaignExperimentErrorEnum
from google.ads.google_ads.v1.proto.errors.campaign_feed_error_pb2 import CampaignFeedErrorEnum as CampaignFeedErrorEnum
from google.ads.google_ads.v1.proto.errors.campaign_shared_set_error_pb2 import CampaignSharedSetErrorEnum as CampaignSharedSetErrorEnum
from google.ads.google_ads.v1.proto.errors.change_status_error_pb2 import ChangeStatusErrorEnum as ChangeStatusErrorEnum
from google.ads.google_ads.v1.proto.errors.collection_size_error_pb2 import CollectionSizeErrorEnum as CollectionSizeErrorEnum
from google.ads.google_ads.v1.proto.errors.context_error_pb2 import ContextErrorEnum as ContextErrorEnum
from google.ads.google_ads.v1.proto.errors.conversion_action_error_pb2 import ConversionActionErrorEnum as ConversionActionErrorEnum
from google.ads.google_ads.v1.proto.errors.conversion_adjustment_upload_error_pb2 import ConversionAdjustmentUploadErrorEnum as ConversionAdjustmentUploadErrorEnum
from google.ads.google_ads.v1.proto.errors.conversion_upload_error_pb2 import ConversionUploadErrorEnum as ConversionUploadErrorEnum
from google.ads.google_ads.v1.proto.errors.country_code_error_pb2 import CountryCodeErrorEnum as CountryCodeErrorEnum
from google.ads.google_ads.v1.proto.errors.criterion_error_pb2 import CriterionErrorEnum as CriterionErrorEnum
from google.ads.google_ads.v1.proto.errors.custom_interest_error_pb2 import CustomInterestErrorEnum as CustomInterestErrorEnum
from google.ads.google_ads.v1.proto.errors.customer_client_link_error_pb2 import CustomerClientLinkErrorEnum as CustomerClientLinkErrorEnum
from google.ads.google_ads.v1.proto.errors.customer_error_pb2 import CustomerErrorEnum as CustomerErrorEnum
from google.ads.google_ads.v1.proto.errors.customer_feed_error_pb2 import CustomerFeedErrorEnum as CustomerFeedErrorEnum
from google.ads.google_ads.v1.proto.errors.customer_manager_link_error_pb2 import CustomerManagerLinkErrorEnum as CustomerManagerLinkErrorEnum
from google.ads.google_ads.v1.proto.errors.database_error_pb2 import DatabaseErrorEnum as DatabaseErrorEnum
from google.ads.google_ads.v1.proto.errors.date_error_pb2 import DateErrorEnum as DateErrorEnum
from google.ads.google_ads.v1.proto.errors.date_range_error_pb2 import DateRangeErrorEnum as DateRangeErrorEnum
from google.ads.google_ads.v1.proto.errors.distinct_error_pb2 import DistinctErrorEnum as DistinctErrorEnum
from google.ads.google_ads.v1.proto.errors.enum_error_pb2 import EnumErrorEnum as EnumErrorEnum
from google.ads.google_ads.v1.proto.errors.errors_pb2 import ErrorCode as ErrorCode
from google.ads.google_ads.v1.proto.errors.errors_pb2 import ErrorDetails as ErrorDetails
from google.ads.google_ads.v1.proto.errors.errors_pb2 import ErrorLocation as ErrorLocation
from google.ads.google_ads.v1.proto.errors.errors_pb2 import GoogleAdsError as GoogleAdsError
from google.ads.google_ads.v1.proto.errors.errors_pb2 import GoogleAdsFailure as GoogleAdsFailure
from google.ads.google_ads.v1.proto.errors.errors_pb2 import PolicyFindingDetails as PolicyFindingDetails
from google.ads.google_ads.v1.proto.errors.errors_pb2 import PolicyViolationDetails as PolicyViolationDetails
from google.ads.google_ads.v1.proto.errors.extension_feed_item_error_pb2 import ExtensionFeedItemErrorEnum as ExtensionFeedItemErrorEnum
from google.ads.google_ads.v1.proto.errors.extension_setting_error_pb2 import ExtensionSettingErrorEnum as ExtensionSettingErrorEnum
from google.ads.google_ads.v1.proto.errors.feed_attribute_reference_error_pb2 import FeedAttributeReferenceErrorEnum as FeedAttributeReferenceErrorEnum
from google.ads.google_ads.v1.proto.errors.feed_error_pb2 import FeedErrorEnum as FeedErrorEnum
from google.ads.google_ads.v1.proto.errors.feed_item_error_pb2 import FeedItemErrorEnum as FeedItemErrorEnum
from google.ads.google_ads.v1.proto.errors.feed_item_target_error_pb2 import FeedItemTargetErrorEnum as FeedItemTargetErrorEnum
from google.ads.google_ads.v1.proto.errors.feed_item_validation_error_pb2 import FeedItemValidationErrorEnum as FeedItemValidationErrorEnum
from google.ads.google_ads.v1.proto.errors.feed_mapping_error_pb2 import FeedMappingErrorEnum as FeedMappingErrorEnum
from google.ads.google_ads.v1.proto.errors.field_error_pb2 import FieldErrorEnum as FieldErrorEnum
from google.ads.google_ads.v1.proto.errors.field_mask_error_pb2 import FieldMaskErrorEnum as FieldMaskErrorEnum
from google.ads.google_ads.v1.proto.errors.function_error_pb2 import FunctionErrorEnum as FunctionErrorEnum
from google.ads.google_ads.v1.proto.errors.function_parsing_error_pb2 import FunctionParsingErrorEnum as FunctionParsingErrorEnum
from google.ads.google_ads.v1.proto.errors.geo_target_constant_suggestion_error_pb2 import GeoTargetConstantSuggestionErrorEnum as GeoTargetConstantSuggestionErrorEnum
from google.ads.google_ads.v1.proto.errors.header_error_pb2 import HeaderErrorEnum as HeaderErrorEnum
from google.ads.google_ads.v1.proto.errors.id_error_pb2 import IdErrorEnum as IdErrorEnum
from google.ads.google_ads.v1.proto.errors.image_error_pb2 import ImageErrorEnum as ImageErrorEnum
from google.ads.google_ads.v1.proto.errors.internal_error_pb2 import InternalErrorEnum as InternalErrorEnum
from google.ads.google_ads.v1.proto.errors.keyword_plan_ad_group_error_pb2 import KeywordPlanAdGroupErrorEnum as KeywordPlanAdGroupErrorEnum
from google.ads.google_ads.v1.proto.errors.keyword_plan_campaign_error_pb2 import KeywordPlanCampaignErrorEnum as KeywordPlanCampaignErrorEnum
from google.ads.google_ads.v1.proto.errors.keyword_plan_error_pb2 import KeywordPlanErrorEnum as KeywordPlanErrorEnum
from google.ads.google_ads.v1.proto.errors.keyword_plan_idea_error_pb2 import KeywordPlanIdeaErrorEnum as KeywordPlanIdeaErrorEnum
from google.ads.google_ads.v1.proto.errors.keyword_plan_keyword_error_pb2 import KeywordPlanKeywordErrorEnum as KeywordPlanKeywordErrorEnum
from google.ads.google_ads.v1.proto.errors.keyword_plan_negative_keyword_error_pb2 import KeywordPlanNegativeKeywordErrorEnum as KeywordPlanNegativeKeywordErrorEnum
from google.ads.google_ads.v1.proto.errors.label_error_pb2 import LabelErrorEnum as LabelErrorEnum
from google.ads.google_ads.v1.proto.errors.language_code_error_pb2 import LanguageCodeErrorEnum as LanguageCodeErrorEnum
from google.ads.google_ads.v1.proto.errors.list_operation_error_pb2 import ListOperationErrorEnum as ListOperationErrorEnum
from google.ads.google_ads.v1.proto.errors.manager_link_error_pb2 import ManagerLinkErrorEnum as ManagerLinkErrorEnum
from google.ads.google_ads.v1.proto.errors.media_bundle_error_pb2 import MediaBundleErrorEnum as MediaBundleErrorEnum
from google.ads.google_ads.v1.proto.errors.media_file_error_pb2 import MediaFileErrorEnum as MediaFileErrorEnum
from google.ads.google_ads.v1.proto.errors.media_upload_error_pb2 import MediaUploadErrorEnum as MediaUploadErrorEnum
from google.ads.google_ads.v1.proto.errors.multiplier_error_pb2 import MultiplierErrorEnum as MultiplierErrorEnum
from google.ads.google_ads.v1.proto.errors.mutate_error_pb2 import MutateErrorEnum as MutateErrorEnum
from google.ads.google_ads.v1.proto.errors.mutate_job_error_pb2 import MutateJobErrorEnum as MutateJobErrorEnum
from google.ads.google_ads.v1.proto.errors.new_resource_creation_error_pb2 import NewResourceCreationErrorEnum as NewResourceCreationErrorEnum
from google.ads.google_ads.v1.proto.errors.not_empty_error_pb2 import NotEmptyErrorEnum as NotEmptyErrorEnum
from google.ads.google_ads.v1.proto.errors.not_whitelisted_error_pb2 import NotWhitelistedErrorEnum as NotWhitelistedErrorEnum
from google.ads.google_ads.v1.proto.errors.null_error_pb2 import NullErrorEnum as NullErrorEnum
from google.ads.google_ads.v1.proto.errors.operation_access_denied_error_pb2 import OperationAccessDeniedErrorEnum as OperationAccessDeniedErrorEnum
from google.ads.google_ads.v1.proto.errors.operator_error_pb2 import OperatorErrorEnum as OperatorErrorEnum
from google.ads.google_ads.v1.proto.errors.partial_failure_error_pb2 import PartialFailureErrorEnum as PartialFailureErrorEnum
from google.ads.google_ads.v1.proto.errors.policy_finding_error_pb2 import PolicyFindingErrorEnum as PolicyFindingErrorEnum
from google.ads.google_ads.v1.proto.errors.policy_validation_parameter_error_pb2 import PolicyValidationParameterErrorEnum as PolicyValidationParameterErrorEnum
from google.ads.google_ads.v1.proto.errors.policy_violation_error_pb2 import PolicyViolationErrorEnum as PolicyViolationErrorEnum
from google.ads.google_ads.v1.proto.errors.query_error_pb2 import QueryErrorEnum as QueryErrorEnum
from google.ads.google_ads.v1.proto.errors.quota_error_pb2 import QuotaErrorEnum as QuotaErrorEnum
from google.ads.google_ads.v1.proto.errors.range_error_pb2 import RangeErrorEnum as RangeErrorEnum
from google.ads.google_ads.v1.proto.errors.recommendation_error_pb2 import RecommendationErrorEnum as RecommendationErrorEnum
from google.ads.google_ads.v1.proto.errors.region_code_error_pb2 import RegionCodeErrorEnum as RegionCodeErrorEnum
from google.ads.google_ads.v1.proto.errors.request_error_pb2 import RequestErrorEnum as RequestErrorEnum
from google.ads.google_ads.v1.proto.errors.resource_access_denied_error_pb2 import ResourceAccessDeniedErrorEnum as ResourceAccessDeniedErrorEnum
from google.ads.google_ads.v1.proto.errors.resource_count_limit_exceeded_error_pb2 import ResourceCountLimitExceededErrorEnum as ResourceCountLimitExceededErrorEnum
from google.ads.google_ads.v1.proto.errors.setting_error_pb2 import SettingErrorEnum as SettingErrorEnum
from google.ads.google_ads.v1.proto.errors.shared_criterion_error_pb2 import SharedCriterionErrorEnum as SharedCriterionErrorEnum
from google.ads.google_ads.v1.proto.errors.shared_set_error_pb2 import SharedSetErrorEnum as SharedSetErrorEnum
from google.ads.google_ads.v1.proto.errors.size_limit_error_pb2 import SizeLimitErrorEnum as SizeLimitErrorEnum
from google.ads.google_ads.v1.proto.errors.string_format_error_pb2 import StringFormatErrorEnum as StringFormatErrorEnum
from google.ads.google_ads.v1.proto.errors.string_length_error_pb2 import StringLengthErrorEnum as StringLengthErrorEnum
from google.ads.google_ads.v1.proto.errors.url_field_error_pb2 import UrlFieldErrorEnum as UrlFieldErrorEnum
from google.ads.google_ads.v1.proto.errors.user_list_error_pb2 import UserListErrorEnum as UserListErrorEnum
from google.ads.google_ads.v1.proto.errors.youtube_video_registration_error_pb2 import YoutubeVideoRegistrationErrorEnum as YoutubeVideoRegistrationErrorEnum
from google.ads.google_ads.v1.proto.resources.account_budget_pb2 import AccountBudget as AccountBudget
from google.ads.google_ads.v1.proto.resources.account_budget_proposal_pb2 import AccountBudgetProposal as AccountBudgetProposal
from google.ads.google_ads.v1.proto.resources.ad_group_ad_label_pb2 import AdGroupAdLabel as AdGroupAdLabel
from google.ads.google_ads.v1.proto.resources.ad_group_ad_pb2 import AdGroupAd as AdGroupAd
from google.ads.google_ads.v1.proto.resources.ad_group_ad_pb2 import AdGroupAdPolicySummary as AdGroupAdPolicySummary
from google.ads.google_ads.v1.proto.resources.ad_group_audience_view_pb2 import AdGroupAudienceView as AdGroupAudienceView
from google.ads.google_ads.v1.proto.resources.ad_group_bid_modifier_pb2 import AdGroupBidModifier as AdGroupBidModifier
from google.ads.google_ads.v1.proto.resources.ad_group_criterion_label_pb2 import AdGroupCriterionLabel as AdGroupCriterionLabel
from google.ads.google_ads.v1.proto.resources.ad_group_criterion_pb2 import AdGroupCriterion as AdGroupCriterion
from google.ads.google_ads.v1.proto.resources.ad_group_criterion_simulation_pb2 import AdGroupCriterionSimulation as AdGroupCriterionSimulation
from google.ads.google_ads.v1.proto.resources.ad_group_extension_setting_pb2 import AdGroupExtensionSetting as AdGroupExtensionSetting
from google.ads.google_ads.v1.proto.resources.ad_group_feed_pb2 import AdGroupFeed as AdGroupFeed
from google.ads.google_ads.v1.proto.resources.ad_group_label_pb2 import AdGroupLabel as AdGroupLabel
from google.ads.google_ads.v1.proto.resources.ad_group_pb2 import AdGroup as AdGroup
from google.ads.google_ads.v1.proto.resources.ad_group_simulation_pb2 import AdGroupSimulation as AdGroupSimulation
from google.ads.google_ads.v1.proto.resources.ad_parameter_pb2 import AdParameter as AdParameter
from google.ads.google_ads.v1.proto.resources.ad_pb2 import Ad as Ad
from google.ads.google_ads.v1.proto.resources.ad_schedule_view_pb2 import AdScheduleView as AdScheduleView
from google.ads.google_ads.v1.proto.resources.age_range_view_pb2 import AgeRangeView as AgeRangeView
from google.ads.google_ads.v1.proto.resources.asset_pb2 import Asset as Asset
from google.ads.google_ads.v1.proto.resources.bidding_strategy_pb2 import BiddingStrategy as BiddingStrategy
from google.ads.google_ads.v1.proto.resources.billing_setup_pb2 import BillingSetup as BillingSetup
from google.ads.google_ads.v1.proto.resources.campaign_audience_view_pb2 import CampaignAudienceView as CampaignAudienceView
from google.ads.google_ads.v1.proto.resources.campaign_bid_modifier_pb2 import CampaignBidModifier as CampaignBidModifier
from google.ads.google_ads.v1.proto.resources.campaign_budget_pb2 import CampaignBudget as CampaignBudget
from google.ads.google_ads.v1.proto.resources.campaign_criterion_pb2 import CampaignCriterion as CampaignCriterion
from google.ads.google_ads.v1.proto.resources.campaign_criterion_simulation_pb2 import CampaignCriterionSimulation as CampaignCriterionSimulation
from google.ads.google_ads.v1.proto.resources.campaign_draft_pb2 import CampaignDraft as CampaignDraft
from google.ads.google_ads.v1.proto.resources.campaign_experiment_pb2 import CampaignExperiment as CampaignExperiment
from google.ads.google_ads.v1.proto.resources.campaign_extension_setting_pb2 import CampaignExtensionSetting as CampaignExtensionSetting
from google.ads.google_ads.v1.proto.resources.campaign_feed_pb2 import CampaignFeed as CampaignFeed
from google.ads.google_ads.v1.proto.resources.campaign_label_pb2 import CampaignLabel as CampaignLabel
from google.ads.google_ads.v1.proto.resources.campaign_pb2 import Campaign as Campaign
from google.ads.google_ads.v1.proto.resources.campaign_shared_set_pb2 import CampaignSharedSet as CampaignSharedSet
from google.ads.google_ads.v1.proto.resources.carrier_constant_pb2 import CarrierConstant as CarrierConstant
from google.ads.google_ads.v1.proto.resources.change_status_pb2 import ChangeStatus as ChangeStatus
from google.ads.google_ads.v1.proto.resources.click_view_pb2 import ClickView as ClickView
from google.ads.google_ads.v1.proto.resources.conversion_action_pb2 import ConversionAction as ConversionAction
from google.ads.google_ads.v1.proto.resources.custom_interest_pb2 import CustomInterest as CustomInterest
from google.ads.google_ads.v1.proto.resources.custom_interest_pb2 import CustomInterestMember as CustomInterestMember
from google.ads.google_ads.v1.proto.resources.customer_client_link_pb2 import CustomerClientLink as CustomerClientLink
from google.ads.google_ads.v1.proto.resources.customer_client_pb2 import CustomerClient as CustomerClient
from google.ads.google_ads.v1.proto.resources.customer_extension_setting_pb2 import CustomerExtensionSetting as CustomerExtensionSetting
from google.ads.google_ads.v1.proto.resources.customer_feed_pb2 import CustomerFeed as CustomerFeed
from google.ads.google_ads.v1.proto.resources.customer_label_pb2 import CustomerLabel as CustomerLabel
from google.ads.google_ads.v1.proto.resources.customer_manager_link_pb2 import CustomerManagerLink as CustomerManagerLink
from google.ads.google_ads.v1.proto.resources.customer_negative_criterion_pb2 import CustomerNegativeCriterion as CustomerNegativeCriterion
from google.ads.google_ads.v1.proto.resources.customer_pb2 import CallReportingSetting as CallReportingSetting
from google.ads.google_ads.v1.proto.resources.customer_pb2 import ConversionTrackingSetting as ConversionTrackingSetting
from google.ads.google_ads.v1.proto.resources.customer_pb2 import Customer as Customer
from google.ads.google_ads.v1.proto.resources.customer_pb2 import RemarketingSetting as RemarketingSetting
from google.ads.google_ads.v1.proto.resources.detail_placement_view_pb2 import DetailPlacementView as DetailPlacementView
from google.ads.google_ads.v1.proto.resources.display_keyword_view_pb2 import DisplayKeywordView as DisplayKeywordView
from google.ads.google_ads.v1.proto.resources.domain_category_pb2 import DomainCategory as DomainCategory
from google.ads.google_ads.v1.proto.resources.dynamic_search_ads_search_term_view_pb2 import DynamicSearchAdsSearchTermView as DynamicSearchAdsSearchTermView
from google.ads.google_ads.v1.proto.resources.expanded_landing_page_view_pb2 import ExpandedLandingPageView as ExpandedLandingPageView
from google.ads.google_ads.v1.proto.resources.extension_feed_item_pb2 import ExtensionFeedItem as ExtensionFeedItem
from google.ads.google_ads.v1.proto.resources.feed_item_pb2 import FeedItem as FeedItem
from google.ads.google_ads.v1.proto.resources.feed_item_pb2 import FeedItemAttributeValue as FeedItemAttributeValue
from google.ads.google_ads.v1.proto.resources.feed_item_pb2 import FeedItemPlaceholderPolicyInfo as FeedItemPlaceholderPolicyInfo
from google.ads.google_ads.v1.proto.resources.feed_item_pb2 import FeedItemValidationError as FeedItemValidationError
from google.ads.google_ads.v1.proto.resources.feed_item_target_pb2 import FeedItemTarget as FeedItemTarget
from google.ads.google_ads.v1.proto.resources.feed_mapping_pb2 import AttributeFieldMapping as AttributeFieldMapping
from google.ads.google_ads.v1.proto.resources.feed_mapping_pb2 import FeedMapping as FeedMapping
from google.ads.google_ads.v1.proto.resources.feed_pb2 import Feed as Feed
from google.ads.google_ads.v1.proto.resources.feed_pb2 import FeedAttribute as FeedAttribute
from google.ads.google_ads.v1.proto.resources.feed_pb2 import FeedAttributeOperation as FeedAttributeOperation
from google.ads.google_ads.v1.proto.resources.feed_placeholder_view_pb2 import FeedPlaceholderView as FeedPlaceholderView
from google.ads.google_ads.v1.proto.resources.gender_view_pb2 import GenderView as GenderView
from google.ads.google_ads.v1.proto.resources.geo_target_constant_pb2 import GeoTargetConstant as GeoTargetConstant
from google.ads.google_ads.v1.proto.resources.geographic_view_pb2 import GeographicView as GeographicView
from google.ads.google_ads.v1.proto.resources.google_ads_field_pb2 import GoogleAdsField as GoogleAdsField
from google.ads.google_ads.v1.proto.resources.group_placement_view_pb2 import GroupPlacementView as GroupPlacementView
from google.ads.google_ads.v1.proto.resources.hotel_group_view_pb2 import HotelGroupView as HotelGroupView
from google.ads.google_ads.v1.proto.resources.hotel_performance_view_pb2 import HotelPerformanceView as HotelPerformanceView
from google.ads.google_ads.v1.proto.resources.keyword_plan_ad_group_pb2 import KeywordPlanAdGroup as KeywordPlanAdGroup
from google.ads.google_ads.v1.proto.resources.keyword_plan_campaign_pb2 import KeywordPlanCampaign as KeywordPlanCampaign
from google.ads.google_ads.v1.proto.resources.keyword_plan_campaign_pb2 import KeywordPlanGeoTarget as KeywordPlanGeoTarget
from google.ads.google_ads.v1.proto.resources.keyword_plan_keyword_pb2 import KeywordPlanKeyword as KeywordPlanKeyword
from google.ads.google_ads.v1.proto.resources.keyword_plan_negative_keyword_pb2 import KeywordPlanNegativeKeyword as KeywordPlanNegativeKeyword
from google.ads.google_ads.v1.proto.resources.keyword_plan_pb2 import KeywordPlan as KeywordPlan
from google.ads.google_ads.v1.proto.resources.keyword_plan_pb2 import KeywordPlanForecastPeriod as KeywordPlanForecastPeriod
from google.ads.google_ads.v1.proto.resources.keyword_view_pb2 import KeywordView as KeywordView
from google.ads.google_ads.v1.proto.resources.label_pb2 import Label as Label
from google.ads.google_ads.v1.proto.resources.landing_page_view_pb2 import LandingPageView as LandingPageView
from google.ads.google_ads.v1.proto.resources.language_constant_pb2 import LanguageConstant as LanguageConstant
from google.ads.google_ads.v1.proto.resources.location_view_pb2 import LocationView as LocationView
from google.ads.google_ads.v1.proto.resources.managed_placement_view_pb2 import ManagedPlacementView as ManagedPlacementView
from google.ads.google_ads.v1.proto.resources.media_file_pb2 import MediaAudio as MediaAudio
from google.ads.google_ads.v1.proto.resources.media_file_pb2 import MediaBundle as MediaBundle
from google.ads.google_ads.v1.proto.resources.media_file_pb2 import MediaFile as MediaFile
from google.ads.google_ads.v1.proto.resources.media_file_pb2 import MediaImage as MediaImage
from google.ads.google_ads.v1.proto.resources.media_file_pb2 import MediaVideo as MediaVideo
from google.ads.google_ads.v1.proto.resources.merchant_center_link_pb2 import MerchantCenterLink as MerchantCenterLink
from google.ads.google_ads.v1.proto.resources.mobile_app_category_constant_pb2 import MobileAppCategoryConstant as MobileAppCategoryConstant
from google.ads.google_ads.v1.proto.resources.mobile_device_constant_pb2 import MobileDeviceConstant as MobileDeviceConstant
from google.ads.google_ads.v1.proto.resources.mutate_job_pb2 import MutateJob as MutateJob
from google.ads.google_ads.v1.proto.resources.operating_system_version_constant_pb2 import OperatingSystemVersionConstant as OperatingSystemVersionConstant
from google.ads.google_ads.v1.proto.resources.paid_organic_search_term_view_pb2 import PaidOrganicSearchTermView as PaidOrganicSearchTermView
from google.ads.google_ads.v1.proto.resources.parental_status_view_pb2 import ParentalStatusView as ParentalStatusView
from google.ads.google_ads.v1.proto.resources.payments_account_pb2 import PaymentsAccount as PaymentsAccount
from google.ads.google_ads.v1.proto.resources.product_bidding_category_constant_pb2 import ProductBiddingCategoryConstant as ProductBiddingCategoryConstant
from google.ads.google_ads.v1.proto.resources.product_group_view_pb2 import ProductGroupView as ProductGroupView
from google.ads.google_ads.v1.proto.resources.recommendation_pb2 import Recommendation as Recommendation
from google.ads.google_ads.v1.proto.resources.remarketing_action_pb2 import RemarketingAction as RemarketingAction
from google.ads.google_ads.v1.proto.resources.search_term_view_pb2 import SearchTermView as SearchTermView
from google.ads.google_ads.v1.proto.resources.shared_criterion_pb2 import SharedCriterion as SharedCriterion
from google.ads.google_ads.v1.proto.resources.shared_set_pb2 import SharedSet as SharedSet
from google.ads.google_ads.v1.proto.resources.shopping_performance_view_pb2 import ShoppingPerformanceView as ShoppingPerformanceView
from google.ads.google_ads.v1.proto.resources.topic_constant_pb2 import TopicConstant as TopicConstant
from google.ads.google_ads.v1.proto.resources.topic_view_pb2 import TopicView as TopicView
from google.ads.google_ads.v1.proto.resources.user_interest_pb2 import UserInterest as UserInterest
from google.ads.google_ads.v1.proto.resources.user_list_pb2 import UserList as UserList
from google.ads.google_ads.v1.proto.resources.video_pb2 import Video as Video
from google.longrunning.operations_pb2 import CancelOperationRequest as CancelOperationRequest
from google.longrunning.operations_pb2 import DeleteOperationRequest as DeleteOperationRequest
from google.longrunning.operations_pb2 import GetOperationRequest as GetOperationRequest
from google.longrunning.operations_pb2 import ListOperationsRequest as ListOperationsRequest
from google.longrunning.operations_pb2 import ListOperationsResponse as ListOperationsResponse
from google.longrunning.operations_pb2 import Operation as Operation
from google.longrunning.operations_pb2 import OperationInfo as OperationInfo
from google.protobuf.any_pb2 import Any as Any
from google.protobuf.empty_pb2 import Empty as Empty
from google.protobuf.field_mask_pb2 import FieldMask as FieldMask
from google.protobuf.wrappers_pb2 import BoolValue as BoolValue
from google.protobuf.wrappers_pb2 import BytesValue as BytesValue
from google.protobuf.wrappers_pb2 import DoubleValue as DoubleValue
from google.protobuf.wrappers_pb2 import FloatValue as FloatValue
from google.protobuf.wrappers_pb2 import Int32Value as Int32Value
from google.protobuf.wrappers_pb2 import Int64Value as Int64Value
from google.protobuf.wrappers_pb2 import StringValue as StringValue
from google.protobuf.wrappers_pb2 import UInt32Value as UInt32Value
from google.protobuf.wrappers_pb2 import UInt64Value as UInt64Value
from google.rpc.status_pb2 import Status as Status
from google.ads.google_ads.v1.proto.services.account_budget_proposal_service_pb2 import AccountBudgetProposalOperation as AccountBudgetProposalOperation
from google.ads.google_ads.v1.proto.services.account_budget_proposal_service_pb2 import GetAccountBudgetProposalRequest as GetAccountBudgetProposalRequest
from google.ads.google_ads.v1.proto.services.account_budget_proposal_service_pb2 import MutateAccountBudgetProposalRequest as MutateAccountBudgetProposalRequest
from google.ads.google_ads.v1.proto.services.account_budget_proposal_service_pb2 import MutateAccountBudgetProposalResponse as MutateAccountBudgetProposalResponse
from google.ads.google_ads.v1.proto.services.account_budget_proposal_service_pb2 import MutateAccountBudgetProposalResult as MutateAccountBudgetProposalResult
from google.ads.google_ads.v1.proto.services.account_budget_service_pb2 import GetAccountBudgetRequest as GetAccountBudgetRequest
from google.ads.google_ads.v1.proto.services.ad_group_ad_label_service_pb2 import AdGroupAdLabelOperation as AdGroupAdLabelOperation
from google.ads.google_ads.v1.proto.services.ad_group_ad_label_service_pb2 import GetAdGroupAdLabelRequest as GetAdGroupAdLabelRequest
from google.ads.google_ads.v1.proto.services.ad_group_ad_label_service_pb2 import MutateAdGroupAdLabelResult as MutateAdGroupAdLabelResult
from google.ads.google_ads.v1.proto.services.ad_group_ad_label_service_pb2 import MutateAdGroupAdLabelsRequest as MutateAdGroupAdLabelsRequest
from google.ads.google_ads.v1.proto.services.ad_group_ad_label_service_pb2 import MutateAdGroupAdLabelsResponse as MutateAdGroupAdLabelsResponse
from google.ads.google_ads.v1.proto.services.ad_group_ad_service_pb2 import AdGroupAdOperation as AdGroupAdOperation
from google.ads.google_ads.v1.proto.services.ad_group_ad_service_pb2 import GetAdGroupAdRequest as GetAdGroupAdRequest
from google.ads.google_ads.v1.proto.services.ad_group_ad_service_pb2 import MutateAdGroupAdResult as MutateAdGroupAdResult
from google.ads.google_ads.v1.proto.services.ad_group_ad_service_pb2 import MutateAdGroupAdsRequest as MutateAdGroupAdsRequest
from google.ads.google_ads.v1.proto.services.ad_group_ad_service_pb2 import MutateAdGroupAdsResponse as MutateAdGroupAdsResponse
from google.ads.google_ads.v1.proto.services.ad_group_audience_view_service_pb2 import GetAdGroupAudienceViewRequest as GetAdGroupAudienceViewRequest
from google.ads.google_ads.v1.proto.services.ad_group_bid_modifier_service_pb2 import AdGroupBidModifierOperation as AdGroupBidModifierOperation
from google.ads.google_ads.v1.proto.services.ad_group_bid_modifier_service_pb2 import GetAdGroupBidModifierRequest as GetAdGroupBidModifierRequest
from google.ads.google_ads.v1.proto.services.ad_group_bid_modifier_service_pb2 import MutateAdGroupBidModifierResult as MutateAdGroupBidModifierResult
from google.ads.google_ads.v1.proto.services.ad_group_bid_modifier_service_pb2 import MutateAdGroupBidModifiersRequest as MutateAdGroupBidModifiersRequest
from google.ads.google_ads.v1.proto.services.ad_group_bid_modifier_service_pb2 import MutateAdGroupBidModifiersResponse as MutateAdGroupBidModifiersResponse
from google.ads.google_ads.v1.proto.services.ad_group_criterion_label_service_pb2 import AdGroupCriterionLabelOperation as AdGroupCriterionLabelOperation
from google.ads.google_ads.v1.proto.services.ad_group_criterion_label_service_pb2 import GetAdGroupCriterionLabelRequest as GetAdGroupCriterionLabelRequest
from google.ads.google_ads.v1.proto.services.ad_group_criterion_label_service_pb2 import MutateAdGroupCriterionLabelResult as MutateAdGroupCriterionLabelResult
from google.ads.google_ads.v1.proto.services.ad_group_criterion_label_service_pb2 import MutateAdGroupCriterionLabelsRequest as MutateAdGroupCriterionLabelsRequest
from google.ads.google_ads.v1.proto.services.ad_group_criterion_label_service_pb2 import MutateAdGroupCriterionLabelsResponse as MutateAdGroupCriterionLabelsResponse
from google.ads.google_ads.v1.proto.services.ad_group_criterion_service_pb2 import AdGroupCriterionOperation as AdGroupCriterionOperation
from google.ads.google_ads.v1.proto.services.ad_group_criterion_service_pb2 import GetAdGroupCriterionRequest as GetAdGroupCriterionRequest
from google.ads.google_ads.v1.proto.services.ad_group_criterion_service_pb2 import MutateAdGroupCriteriaRequest as MutateAdGroupCriteriaRequest
from google.ads.google_ads.v1.proto.services.ad_group_criterion_service_pb2 import MutateAdGroupCriteriaResponse as MutateAdGroupCriteriaResponse
from google.ads.google_ads.v1.proto.services.ad_group_criterion_service_pb2 import MutateAdGroupCriterionResult as MutateAdGroupCriterionResult
from google.ads.google_ads.v1.proto.services.ad_group_criterion_simulation_service_pb2 import GetAdGroupCriterionSimulationRequest as GetAdGroupCriterionSimulationRequest
from google.ads.google_ads.v1.proto.services.ad_group_extension_setting_service_pb2 import AdGroupExtensionSettingOperation as AdGroupExtensionSettingOperation
from google.ads.google_ads.v1.proto.services.ad_group_extension_setting_service_pb2 import GetAdGroupExtensionSettingRequest as GetAdGroupExtensionSettingRequest
from google.ads.google_ads.v1.proto.services.ad_group_extension_setting_service_pb2 import MutateAdGroupExtensionSettingResult as MutateAdGroupExtensionSettingResult
from google.ads.google_ads.v1.proto.services.ad_group_extension_setting_service_pb2 import MutateAdGroupExtensionSettingsRequest as MutateAdGroupExtensionSettingsRequest
from google.ads.google_ads.v1.proto.services.ad_group_extension_setting_service_pb2 import MutateAdGroupExtensionSettingsResponse as MutateAdGroupExtensionSettingsResponse
from google.ads.google_ads.v1.proto.services.ad_group_feed_service_pb2 import AdGroupFeedOperation as AdGroupFeedOperation
from google.ads.google_ads.v1.proto.services.ad_group_feed_service_pb2 import GetAdGroupFeedRequest as GetAdGroupFeedRequest
from google.ads.google_ads.v1.proto.services.ad_group_feed_service_pb2 import MutateAdGroupFeedResult as MutateAdGroupFeedResult
from google.ads.google_ads.v1.proto.services.ad_group_feed_service_pb2 import MutateAdGroupFeedsRequest as MutateAdGroupFeedsRequest
from google.ads.google_ads.v1.proto.services.ad_group_feed_service_pb2 import MutateAdGroupFeedsResponse as MutateAdGroupFeedsResponse
from google.ads.google_ads.v1.proto.services.ad_group_label_service_pb2 import AdGroupLabelOperation as AdGroupLabelOperation
from google.ads.google_ads.v1.proto.services.ad_group_label_service_pb2 import GetAdGroupLabelRequest as GetAdGroupLabelRequest
from google.ads.google_ads.v1.proto.services.ad_group_label_service_pb2 import MutateAdGroupLabelResult as MutateAdGroupLabelResult
from google.ads.google_ads.v1.proto.services.ad_group_label_service_pb2 import MutateAdGroupLabelsRequest as MutateAdGroupLabelsRequest
from google.ads.google_ads.v1.proto.services.ad_group_label_service_pb2 import MutateAdGroupLabelsResponse as MutateAdGroupLabelsResponse
from google.ads.google_ads.v1.proto.services.ad_group_service_pb2 import AdGroupOperation as AdGroupOperation
from google.ads.google_ads.v1.proto.services.ad_group_service_pb2 import GetAdGroupRequest as GetAdGroupRequest
from google.ads.google_ads.v1.proto.services.ad_group_service_pb2 import MutateAdGroupResult as MutateAdGroupResult
from google.ads.google_ads.v1.proto.services.ad_group_service_pb2 import MutateAdGroupsRequest as MutateAdGroupsRequest
from google.ads.google_ads.v1.proto.services.ad_group_service_pb2 import MutateAdGroupsResponse as MutateAdGroupsResponse
from google.ads.google_ads.v1.proto.services.ad_group_simulation_service_pb2 import GetAdGroupSimulationRequest as GetAdGroupSimulationRequest
from google.ads.google_ads.v1.proto.services.ad_parameter_service_pb2 import AdParameterOperation as AdParameterOperation
from google.ads.google_ads.v1.proto.services.ad_parameter_service_pb2 import GetAdParameterRequest as GetAdParameterRequest
from google.ads.google_ads.v1.proto.services.ad_parameter_service_pb2 import MutateAdParameterResult as MutateAdParameterResult
from google.ads.google_ads.v1.proto.services.ad_parameter_service_pb2 import MutateAdParametersRequest as MutateAdParametersRequest
from google.ads.google_ads.v1.proto.services.ad_parameter_service_pb2 import MutateAdParametersResponse as MutateAdParametersResponse
from google.ads.google_ads.v1.proto.services.ad_schedule_view_service_pb2 import GetAdScheduleViewRequest as GetAdScheduleViewRequest
from google.ads.google_ads.v1.proto.services.age_range_view_service_pb2 import GetAgeRangeViewRequest as GetAgeRangeViewRequest
from google.ads.google_ads.v1.proto.services.asset_service_pb2 import AssetOperation as AssetOperation
from google.ads.google_ads.v1.proto.services.asset_service_pb2 import GetAssetRequest as GetAssetRequest
from google.ads.google_ads.v1.proto.services.asset_service_pb2 import MutateAssetResult as MutateAssetResult
from google.ads.google_ads.v1.proto.services.asset_service_pb2 import MutateAssetsRequest as MutateAssetsRequest
from google.ads.google_ads.v1.proto.services.asset_service_pb2 import MutateAssetsResponse as MutateAssetsResponse
from google.ads.google_ads.v1.proto.services.bidding_strategy_service_pb2 import BiddingStrategyOperation as BiddingStrategyOperation
from google.ads.google_ads.v1.proto.services.bidding_strategy_service_pb2 import GetBiddingStrategyRequest as GetBiddingStrategyRequest
from google.ads.google_ads.v1.proto.services.bidding_strategy_service_pb2 import MutateBiddingStrategiesRequest as MutateBiddingStrategiesRequest
from google.ads.google_ads.v1.proto.services.bidding_strategy_service_pb2 import MutateBiddingStrategiesResponse as MutateBiddingStrategiesResponse
from google.ads.google_ads.v1.proto.services.bidding_strategy_service_pb2 import MutateBiddingStrategyResult as MutateBiddingStrategyResult
from google.ads.google_ads.v1.proto.services.billing_setup_service_pb2 import BillingSetupOperation as BillingSetupOperation
from google.ads.google_ads.v1.proto.services.billing_setup_service_pb2 import GetBillingSetupRequest as GetBillingSetupRequest
from google.ads.google_ads.v1.proto.services.billing_setup_service_pb2 import MutateBillingSetupRequest as MutateBillingSetupRequest
from google.ads.google_ads.v1.proto.services.billing_setup_service_pb2 import MutateBillingSetupResponse as MutateBillingSetupResponse
from google.ads.google_ads.v1.proto.services.billing_setup_service_pb2 import MutateBillingSetupResult as MutateBillingSetupResult
from google.ads.google_ads.v1.proto.services.campaign_audience_view_service_pb2 import GetCampaignAudienceViewRequest as GetCampaignAudienceViewRequest
from google.ads.google_ads.v1.proto.services.campaign_bid_modifier_service_pb2 import CampaignBidModifierOperation as CampaignBidModifierOperation
from google.ads.google_ads.v1.proto.services.campaign_bid_modifier_service_pb2 import GetCampaignBidModifierRequest as GetCampaignBidModifierRequest
from google.ads.google_ads.v1.proto.services.campaign_bid_modifier_service_pb2 import MutateCampaignBidModifierResult as MutateCampaignBidModifierResult
from google.ads.google_ads.v1.proto.services.campaign_bid_modifier_service_pb2 import MutateCampaignBidModifiersRequest as MutateCampaignBidModifiersRequest
from google.ads.google_ads.v1.proto.services.campaign_bid_modifier_service_pb2 import MutateCampaignBidModifiersResponse as MutateCampaignBidModifiersResponse
from google.ads.google_ads.v1.proto.services.campaign_budget_service_pb2 import CampaignBudgetOperation as CampaignBudgetOperation
from google.ads.google_ads.v1.proto.services.campaign_budget_service_pb2 import GetCampaignBudgetRequest as GetCampaignBudgetRequest
from google.ads.google_ads.v1.proto.services.campaign_budget_service_pb2 import MutateCampaignBudgetResult as MutateCampaignBudgetResult
from google.ads.google_ads.v1.proto.services.campaign_budget_service_pb2 import MutateCampaignBudgetsRequest as MutateCampaignBudgetsRequest
from google.ads.google_ads.v1.proto.services.campaign_budget_service_pb2 import MutateCampaignBudgetsResponse as MutateCampaignBudgetsResponse
from google.ads.google_ads.v1.proto.services.campaign_criterion_service_pb2 import CampaignCriterionOperation as CampaignCriterionOperation
from google.ads.google_ads.v1.proto.services.campaign_criterion_service_pb2 import GetCampaignCriterionRequest as GetCampaignCriterionRequest
from google.ads.google_ads.v1.proto.services.campaign_criterion_service_pb2 import MutateCampaignCriteriaRequest as MutateCampaignCriteriaRequest
from google.ads.google_ads.v1.proto.services.campaign_criterion_service_pb2 import MutateCampaignCriteriaResponse as MutateCampaignCriteriaResponse
from google.ads.google_ads.v1.proto.services.campaign_criterion_service_pb2 import MutateCampaignCriterionResult as MutateCampaignCriterionResult
from google.ads.google_ads.v1.proto.services.campaign_criterion_simulation_service_pb2 import GetCampaignCriterionSimulationRequest as GetCampaignCriterionSimulationRequest
from google.ads.google_ads.v1.proto.services.campaign_draft_service_pb2 import CampaignDraftOperation as CampaignDraftOperation
from google.ads.google_ads.v1.proto.services.campaign_draft_service_pb2 import GetCampaignDraftRequest as GetCampaignDraftRequest
from google.ads.google_ads.v1.proto.services.campaign_draft_service_pb2 import ListCampaignDraftAsyncErrorsRequest as ListCampaignDraftAsyncErrorsRequest
from google.ads.google_ads.v1.proto.services.campaign_draft_service_pb2 import ListCampaignDraftAsyncErrorsResponse as ListCampaignDraftAsyncErrorsResponse
from google.ads.google_ads.v1.proto.services.campaign_draft_service_pb2 import MutateCampaignDraftResult as MutateCampaignDraftResult
from google.ads.google_ads.v1.proto.services.campaign_draft_service_pb2 import MutateCampaignDraftsRequest as MutateCampaignDraftsRequest
from google.ads.google_ads.v1.proto.services.campaign_draft_service_pb2 import MutateCampaignDraftsResponse as MutateCampaignDraftsResponse
from google.ads.google_ads.v1.proto.services.campaign_draft_service_pb2 import PromoteCampaignDraftRequest as PromoteCampaignDraftRequest
from google.ads.google_ads.v1.proto.services.campaign_experiment_service_pb2 import CampaignExperimentOperation as CampaignExperimentOperation
from google.ads.google_ads.v1.proto.services.campaign_experiment_service_pb2 import CreateCampaignExperimentMetadata as CreateCampaignExperimentMetadata
from google.ads.google_ads.v1.proto.services.campaign_experiment_service_pb2 import CreateCampaignExperimentRequest as CreateCampaignExperimentRequest
from google.ads.google_ads.v1.proto.services.campaign_experiment_service_pb2 import EndCampaignExperimentRequest as EndCampaignExperimentRequest
from google.ads.google_ads.v1.proto.services.campaign_experiment_service_pb2 import GetCampaignExperimentRequest as GetCampaignExperimentRequest
from google.ads.google_ads.v1.proto.services.campaign_experiment_service_pb2 import GraduateCampaignExperimentRequest as GraduateCampaignExperimentRequest
from google.ads.google_ads.v1.proto.services.campaign_experiment_service_pb2 import GraduateCampaignExperimentResponse as GraduateCampaignExperimentResponse
from google.ads.google_ads.v1.proto.services.campaign_experiment_service_pb2 import ListCampaignExperimentAsyncErrorsRequest as ListCampaignExperimentAsyncErrorsRequest
from google.ads.google_ads.v1.proto.services.campaign_experiment_service_pb2 import ListCampaignExperimentAsyncErrorsResponse as ListCampaignExperimentAsyncErrorsResponse
from google.ads.google_ads.v1.proto.services.campaign_experiment_service_pb2 import MutateCampaignExperimentResult as MutateCampaignExperimentResult
from google.ads.google_ads.v1.proto.services.campaign_experiment_service_pb2 import MutateCampaignExperimentsRequest as MutateCampaignExperimentsRequest
from google.ads.google_ads.v1.proto.services.campaign_experiment_service_pb2 import MutateCampaignExperimentsResponse as MutateCampaignExperimentsResponse
from google.ads.google_ads.v1.proto.services.campaign_experiment_service_pb2 import PromoteCampaignExperimentRequest as PromoteCampaignExperimentRequest
from google.ads.google_ads.v1.proto.services.campaign_extension_setting_service_pb2 import CampaignExtensionSettingOperation as CampaignExtensionSettingOperation
from google.ads.google_ads.v1.proto.services.campaign_extension_setting_service_pb2 import GetCampaignExtensionSettingRequest as GetCampaignExtensionSettingRequest
from google.ads.google_ads.v1.proto.services.campaign_extension_setting_service_pb2 import MutateCampaignExtensionSettingResult as MutateCampaignExtensionSettingResult
from google.ads.google_ads.v1.proto.services.campaign_extension_setting_service_pb2 import MutateCampaignExtensionSettingsRequest as MutateCampaignExtensionSettingsRequest
from google.ads.google_ads.v1.proto.services.campaign_extension_setting_service_pb2 import MutateCampaignExtensionSettingsResponse as MutateCampaignExtensionSettingsResponse
from google.ads.google_ads.v1.proto.services.campaign_feed_service_pb2 import CampaignFeedOperation as CampaignFeedOperation
from google.ads.google_ads.v1.proto.services.campaign_feed_service_pb2 import GetCampaignFeedRequest as GetCampaignFeedRequest
from google.ads.google_ads.v1.proto.services.campaign_feed_service_pb2 import MutateCampaignFeedResult as MutateCampaignFeedResult
from google.ads.google_ads.v1.proto.services.campaign_feed_service_pb2 import MutateCampaignFeedsRequest as MutateCampaignFeedsRequest
from google.ads.google_ads.v1.proto.services.campaign_feed_service_pb2 import MutateCampaignFeedsResponse as MutateCampaignFeedsResponse
from google.ads.google_ads.v1.proto.services.campaign_label_service_pb2 import CampaignLabelOperation as CampaignLabelOperation
from google.ads.google_ads.v1.proto.services.campaign_label_service_pb2 import GetCampaignLabelRequest as GetCampaignLabelRequest
from google.ads.google_ads.v1.proto.services.campaign_label_service_pb2 import MutateCampaignLabelResult as MutateCampaignLabelResult
from google.ads.google_ads.v1.proto.services.campaign_label_service_pb2 import MutateCampaignLabelsRequest as MutateCampaignLabelsRequest
from google.ads.google_ads.v1.proto.services.campaign_label_service_pb2 import MutateCampaignLabelsResponse as MutateCampaignLabelsResponse
from google.ads.google_ads.v1.proto.services.campaign_service_pb2 import CampaignOperation as CampaignOperation
from google.ads.google_ads.v1.proto.services.campaign_service_pb2 import GetCampaignRequest as GetCampaignRequest
from google.ads.google_ads.v1.proto.services.campaign_service_pb2 import MutateCampaignResult as MutateCampaignResult
from google.ads.google_ads.v1.proto.services.campaign_service_pb2 import MutateCampaignsRequest as MutateCampaignsRequest
from google.ads.google_ads.v1.proto.services.campaign_service_pb2 import MutateCampaignsResponse as MutateCampaignsResponse
from google.ads.google_ads.v1.proto.services.campaign_shared_set_service_pb2 import CampaignSharedSetOperation as CampaignSharedSetOperation
from google.ads.google_ads.v1.proto.services.campaign_shared_set_service_pb2 import GetCampaignSharedSetRequest as GetCampaignSharedSetRequest
from google.ads.google_ads.v1.proto.services.campaign_shared_set_service_pb2 import MutateCampaignSharedSetResult as MutateCampaignSharedSetResult
from google.ads.google_ads.v1.proto.services.campaign_shared_set_service_pb2 import MutateCampaignSharedSetsRequest as MutateCampaignSharedSetsRequest
from google.ads.google_ads.v1.proto.services.campaign_shared_set_service_pb2 import MutateCampaignSharedSetsResponse as MutateCampaignSharedSetsResponse
from google.ads.google_ads.v1.proto.services.carrier_constant_service_pb2 import GetCarrierConstantRequest as GetCarrierConstantRequest
from google.ads.google_ads.v1.proto.services.change_status_service_pb2 import GetChangeStatusRequest as GetChangeStatusRequest
from google.ads.google_ads.v1.proto.services.click_view_service_pb2 import GetClickViewRequest as GetClickViewRequest
from google.ads.google_ads.v1.proto.services.conversion_action_service_pb2 import ConversionActionOperation as ConversionActionOperation
from google.ads.google_ads.v1.proto.services.conversion_action_service_pb2 import GetConversionActionRequest as GetConversionActionRequest
from google.ads.google_ads.v1.proto.services.conversion_action_service_pb2 import MutateConversionActionResult as MutateConversionActionResult
from google.ads.google_ads.v1.proto.services.conversion_action_service_pb2 import MutateConversionActionsRequest as MutateConversionActionsRequest
from google.ads.google_ads.v1.proto.services.conversion_action_service_pb2 import MutateConversionActionsResponse as MutateConversionActionsResponse
from google.ads.google_ads.v1.proto.services.conversion_adjustment_upload_service_pb2 import ConversionAdjustment as ConversionAdjustment
from google.ads.google_ads.v1.proto.services.conversion_adjustment_upload_service_pb2 import ConversionAdjustmentResult as ConversionAdjustmentResult
from google.ads.google_ads.v1.proto.services.conversion_adjustment_upload_service_pb2 import GclidDateTimePair as GclidDateTimePair
from google.ads.google_ads.v1.proto.services.conversion_adjustment_upload_service_pb2 import RestatementValue as RestatementValue
from google.ads.google_ads.v1.proto.services.conversion_adjustment_upload_service_pb2 import UploadConversionAdjustmentsRequest as UploadConversionAdjustmentsRequest
from google.ads.google_ads.v1.proto.services.conversion_adjustment_upload_service_pb2 import UploadConversionAdjustmentsResponse as UploadConversionAdjustmentsResponse
from google.ads.google_ads.v1.proto.services.conversion_upload_service_pb2 import CallConversion as CallConversion
from google.ads.google_ads.v1.proto.services.conversion_upload_service_pb2 import CallConversionResult as CallConversionResult
from google.ads.google_ads.v1.proto.services.conversion_upload_service_pb2 import ClickConversion as ClickConversion
from google.ads.google_ads.v1.proto.services.conversion_upload_service_pb2 import ClickConversionResult as ClickConversionResult
from google.ads.google_ads.v1.proto.services.conversion_upload_service_pb2 import ExternalAttributionData as ExternalAttributionData
from google.ads.google_ads.v1.proto.services.conversion_upload_service_pb2 import UploadCallConversionsRequest as UploadCallConversionsRequest
from google.ads.google_ads.v1.proto.services.conversion_upload_service_pb2 import UploadCallConversionsResponse as UploadCallConversionsResponse
from google.ads.google_ads.v1.proto.services.conversion_upload_service_pb2 import UploadClickConversionsRequest as UploadClickConversionsRequest
from google.ads.google_ads.v1.proto.services.conversion_upload_service_pb2 import UploadClickConversionsResponse as UploadClickConversionsResponse
from google.ads.google_ads.v1.proto.services.custom_interest_service_pb2 import CustomInterestOperation as CustomInterestOperation
from google.ads.google_ads.v1.proto.services.custom_interest_service_pb2 import GetCustomInterestRequest as GetCustomInterestRequest
from google.ads.google_ads.v1.proto.services.custom_interest_service_pb2 import MutateCustomInterestResult as MutateCustomInterestResult
from google.ads.google_ads.v1.proto.services.custom_interest_service_pb2 import MutateCustomInterestsRequest as MutateCustomInterestsRequest
from google.ads.google_ads.v1.proto.services.custom_interest_service_pb2 import MutateCustomInterestsResponse as MutateCustomInterestsResponse
from google.ads.google_ads.v1.proto.services.customer_client_link_service_pb2 import CustomerClientLinkOperation as CustomerClientLinkOperation
from google.ads.google_ads.v1.proto.services.customer_client_link_service_pb2 import GetCustomerClientLinkRequest as GetCustomerClientLinkRequest
from google.ads.google_ads.v1.proto.services.customer_client_link_service_pb2 import MutateCustomerClientLinkRequest as MutateCustomerClientLinkRequest
from google.ads.google_ads.v1.proto.services.customer_client_link_service_pb2 import MutateCustomerClientLinkResponse as MutateCustomerClientLinkResponse
from google.ads.google_ads.v1.proto.services.customer_client_link_service_pb2 import MutateCustomerClientLinkResult as MutateCustomerClientLinkResult
from google.ads.google_ads.v1.proto.services.customer_client_service_pb2 import GetCustomerClientRequest as GetCustomerClientRequest
from google.ads.google_ads.v1.proto.services.customer_extension_setting_service_pb2 import CustomerExtensionSettingOperation as CustomerExtensionSettingOperation
from google.ads.google_ads.v1.proto.services.customer_extension_setting_service_pb2 import GetCustomerExtensionSettingRequest as GetCustomerExtensionSettingRequest
from google.ads.google_ads.v1.proto.services.customer_extension_setting_service_pb2 import MutateCustomerExtensionSettingResult as MutateCustomerExtensionSettingResult
from google.ads.google_ads.v1.proto.services.customer_extension_setting_service_pb2 import MutateCustomerExtensionSettingsRequest as MutateCustomerExtensionSettingsRequest
from google.ads.google_ads.v1.proto.services.customer_extension_setting_service_pb2 import MutateCustomerExtensionSettingsResponse as MutateCustomerExtensionSettingsResponse
from google.ads.google_ads.v1.proto.services.customer_feed_service_pb2 import CustomerFeedOperation as CustomerFeedOperation
from google.ads.google_ads.v1.proto.services.customer_feed_service_pb2 import GetCustomerFeedRequest as GetCustomerFeedRequest
from google.ads.google_ads.v1.proto.services.customer_feed_service_pb2 import MutateCustomerFeedResult as MutateCustomerFeedResult
from google.ads.google_ads.v1.proto.services.customer_feed_service_pb2 import MutateCustomerFeedsRequest as MutateCustomerFeedsRequest
from google.ads.google_ads.v1.proto.services.customer_feed_service_pb2 import MutateCustomerFeedsResponse as MutateCustomerFeedsResponse
from google.ads.google_ads.v1.proto.services.customer_label_service_pb2 import CustomerLabelOperation as CustomerLabelOperation
from google.ads.google_ads.v1.proto.services.customer_label_service_pb2 import GetCustomerLabelRequest as GetCustomerLabelRequest
from google.ads.google_ads.v1.proto.services.customer_label_service_pb2 import MutateCustomerLabelResult as MutateCustomerLabelResult
from google.ads.google_ads.v1.proto.services.customer_label_service_pb2 import MutateCustomerLabelsRequest as MutateCustomerLabelsRequest
from google.ads.google_ads.v1.proto.services.customer_label_service_pb2 import MutateCustomerLabelsResponse as MutateCustomerLabelsResponse
from google.ads.google_ads.v1.proto.services.customer_manager_link_service_pb2 import CustomerManagerLinkOperation as CustomerManagerLinkOperation
from google.ads.google_ads.v1.proto.services.customer_manager_link_service_pb2 import GetCustomerManagerLinkRequest as GetCustomerManagerLinkRequest
from google.ads.google_ads.v1.proto.services.customer_manager_link_service_pb2 import MutateCustomerManagerLinkRequest as MutateCustomerManagerLinkRequest
from google.ads.google_ads.v1.proto.services.customer_manager_link_service_pb2 import MutateCustomerManagerLinkResponse as MutateCustomerManagerLinkResponse
from google.ads.google_ads.v1.proto.services.customer_manager_link_service_pb2 import MutateCustomerManagerLinkResult as MutateCustomerManagerLinkResult
from google.ads.google_ads.v1.proto.services.customer_negative_criterion_service_pb2 import CustomerNegativeCriterionOperation as CustomerNegativeCriterionOperation
from google.ads.google_ads.v1.proto.services.customer_negative_criterion_service_pb2 import GetCustomerNegativeCriterionRequest as GetCustomerNegativeCriterionRequest
from google.ads.google_ads.v1.proto.services.customer_negative_criterion_service_pb2 import MutateCustomerNegativeCriteriaRequest as MutateCustomerNegativeCriteriaRequest
from google.ads.google_ads.v1.proto.services.customer_negative_criterion_service_pb2 import MutateCustomerNegativeCriteriaResponse as MutateCustomerNegativeCriteriaResponse
from google.ads.google_ads.v1.proto.services.customer_negative_criterion_service_pb2 import MutateCustomerNegativeCriteriaResult as MutateCustomerNegativeCriteriaResult
from google.ads.google_ads.v1.proto.services.customer_service_pb2 import CreateCustomerClientRequest as CreateCustomerClientRequest
from google.ads.google_ads.v1.proto.services.customer_service_pb2 import CreateCustomerClientResponse as CreateCustomerClientResponse
from google.ads.google_ads.v1.proto.services.customer_service_pb2 import CustomerOperation as CustomerOperation
from google.ads.google_ads.v1.proto.services.customer_service_pb2 import GetCustomerRequest as GetCustomerRequest
from google.ads.google_ads.v1.proto.services.customer_service_pb2 import ListAccessibleCustomersRequest as ListAccessibleCustomersRequest
from google.ads.google_ads.v1.proto.services.customer_service_pb2 import ListAccessibleCustomersResponse as ListAccessibleCustomersResponse
from google.ads.google_ads.v1.proto.services.customer_service_pb2 import MutateCustomerRequest as MutateCustomerRequest
from google.ads.google_ads.v1.proto.services.customer_service_pb2 import MutateCustomerResponse as MutateCustomerResponse
from google.ads.google_ads.v1.proto.services.customer_service_pb2 import MutateCustomerResult as MutateCustomerResult
from google.ads.google_ads.v1.proto.services.detail_placement_view_service_pb2 import GetDetailPlacementViewRequest as GetDetailPlacementViewRequest
from google.ads.google_ads.v1.proto.services.display_keyword_view_service_pb2 import GetDisplayKeywordViewRequest as GetDisplayKeywordViewRequest
from google.ads.google_ads.v1.proto.services.domain_category_service_pb2 import GetDomainCategoryRequest as GetDomainCategoryRequest
from google.ads.google_ads.v1.proto.services.dynamic_search_ads_search_term_view_service_pb2 import GetDynamicSearchAdsSearchTermViewRequest as GetDynamicSearchAdsSearchTermViewRequest
from google.ads.google_ads.v1.proto.services.expanded_landing_page_view_service_pb2 import GetExpandedLandingPageViewRequest as GetExpandedLandingPageViewRequest
from google.ads.google_ads.v1.proto.services.extension_feed_item_service_pb2 import ExtensionFeedItemOperation as ExtensionFeedItemOperation
from google.ads.google_ads.v1.proto.services.extension_feed_item_service_pb2 import GetExtensionFeedItemRequest as GetExtensionFeedItemRequest
from google.ads.google_ads.v1.proto.services.extension_feed_item_service_pb2 import MutateExtensionFeedItemResult as MutateExtensionFeedItemResult
from google.ads.google_ads.v1.proto.services.extension_feed_item_service_pb2 import MutateExtensionFeedItemsRequest as MutateExtensionFeedItemsRequest
from google.ads.google_ads.v1.proto.services.extension_feed_item_service_pb2 import MutateExtensionFeedItemsResponse as MutateExtensionFeedItemsResponse
from google.ads.google_ads.v1.proto.services.feed_item_service_pb2 import FeedItemOperation as FeedItemOperation
from google.ads.google_ads.v1.proto.services.feed_item_service_pb2 import GetFeedItemRequest as GetFeedItemRequest
from google.ads.google_ads.v1.proto.services.feed_item_service_pb2 import MutateFeedItemResult as MutateFeedItemResult
from google.ads.google_ads.v1.proto.services.feed_item_service_pb2 import MutateFeedItemsRequest as MutateFeedItemsRequest
from google.ads.google_ads.v1.proto.services.feed_item_service_pb2 import MutateFeedItemsResponse as MutateFeedItemsResponse
from google.ads.google_ads.v1.proto.services.feed_item_target_service_pb2 import FeedItemTargetOperation as FeedItemTargetOperation
from google.ads.google_ads.v1.proto.services.feed_item_target_service_pb2 import GetFeedItemTargetRequest as GetFeedItemTargetRequest
from google.ads.google_ads.v1.proto.services.feed_item_target_service_pb2 import MutateFeedItemTargetResult as MutateFeedItemTargetResult
from google.ads.google_ads.v1.proto.services.feed_item_target_service_pb2 import MutateFeedItemTargetsRequest as MutateFeedItemTargetsRequest
from google.ads.google_ads.v1.proto.services.feed_item_target_service_pb2 import MutateFeedItemTargetsResponse as MutateFeedItemTargetsResponse
from google.ads.google_ads.v1.proto.services.feed_mapping_service_pb2 import FeedMappingOperation as FeedMappingOperation
from google.ads.google_ads.v1.proto.services.feed_mapping_service_pb2 import GetFeedMappingRequest as GetFeedMappingRequest
from google.ads.google_ads.v1.proto.services.feed_mapping_service_pb2 import MutateFeedMappingResult as MutateFeedMappingResult
from google.ads.google_ads.v1.proto.services.feed_mapping_service_pb2 import MutateFeedMappingsRequest as MutateFeedMappingsRequest
from google.ads.google_ads.v1.proto.services.feed_mapping_service_pb2 import MutateFeedMappingsResponse as MutateFeedMappingsResponse
from google.ads.google_ads.v1.proto.services.feed_placeholder_view_service_pb2 import GetFeedPlaceholderViewRequest as GetFeedPlaceholderViewRequest
from google.ads.google_ads.v1.proto.services.feed_service_pb2 import FeedOperation as FeedOperation
from google.ads.google_ads.v1.proto.services.feed_service_pb2 import GetFeedRequest as GetFeedRequest
from google.ads.google_ads.v1.proto.services.feed_service_pb2 import MutateFeedResult as MutateFeedResult
from google.ads.google_ads.v1.proto.services.feed_service_pb2 import MutateFeedsRequest as MutateFeedsRequest
from google.ads.google_ads.v1.proto.services.feed_service_pb2 import MutateFeedsResponse as MutateFeedsResponse
from google.ads.google_ads.v1.proto.services.gender_view_service_pb2 import GetGenderViewRequest as GetGenderViewRequest
from google.ads.google_ads.v1.proto.services.geo_target_constant_service_pb2 import GeoTargetConstantSuggestion as GeoTargetConstantSuggestion
from google.ads.google_ads.v1.proto.services.geo_target_constant_service_pb2 import GetGeoTargetConstantRequest as GetGeoTargetConstantRequest
from google.ads.google_ads.v1.proto.services.geo_target_constant_service_pb2 import SuggestGeoTargetConstantsRequest as SuggestGeoTargetConstantsRequest
from google.ads.google_ads.v1.proto.services.geo_target_constant_service_pb2 import SuggestGeoTargetConstantsResponse as SuggestGeoTargetConstantsResponse
from google.ads.google_ads.v1.proto.services.geographic_view_service_pb2 import GetGeographicViewRequest as GetGeographicViewRequest
from google.ads.google_ads.v1.proto.services.google_ads_field_service_pb2 import GetGoogleAdsFieldRequest as GetGoogleAdsFieldRequest
from google.ads.google_ads.v1.proto.services.google_ads_field_service_pb2 import SearchGoogleAdsFieldsRequest as SearchGoogleAdsFieldsRequest
from google.ads.google_ads.v1.proto.services.google_ads_field_service_pb2 import SearchGoogleAdsFieldsResponse as SearchGoogleAdsFieldsResponse
from google.ads.google_ads.v1.proto.services.google_ads_service_pb2 import GoogleAdsRow as GoogleAdsRow
from google.ads.google_ads.v1.proto.services.google_ads_service_pb2 import MutateGoogleAdsRequest as MutateGoogleAdsRequest
from google.ads.google_ads.v1.proto.services.google_ads_service_pb2 import MutateGoogleAdsResponse as MutateGoogleAdsResponse
from google.ads.google_ads.v1.proto.services.google_ads_service_pb2 import MutateOperation as MutateOperation
from google.ads.google_ads.v1.proto.services.google_ads_service_pb2 import MutateOperationResponse as MutateOperationResponse
from google.ads.google_ads.v1.proto.services.google_ads_service_pb2 import SearchGoogleAdsRequest as SearchGoogleAdsRequest
from google.ads.google_ads.v1.proto.services.google_ads_service_pb2 import SearchGoogleAdsResponse as SearchGoogleAdsResponse
from google.ads.google_ads.v1.proto.services.group_placement_view_service_pb2 import GetGroupPlacementViewRequest as GetGroupPlacementViewRequest
from google.ads.google_ads.v1.proto.services.hotel_group_view_service_pb2 import GetHotelGroupViewRequest as GetHotelGroupViewRequest
from google.ads.google_ads.v1.proto.services.hotel_performance_view_service_pb2 import GetHotelPerformanceViewRequest as GetHotelPerformanceViewRequest
from google.ads.google_ads.v1.proto.services.keyword_plan_ad_group_service_pb2 import GetKeywordPlanAdGroupRequest as GetKeywordPlanAdGroupRequest
from google.ads.google_ads.v1.proto.services.keyword_plan_ad_group_service_pb2 import KeywordPlanAdGroupOperation as KeywordPlanAdGroupOperation
from google.ads.google_ads.v1.proto.services.keyword_plan_ad_group_service_pb2 import MutateKeywordPlanAdGroupResult as MutateKeywordPlanAdGroupResult
from google.ads.google_ads.v1.proto.services.keyword_plan_ad_group_service_pb2 import MutateKeywordPlanAdGroupsRequest as MutateKeywordPlanAdGroupsRequest
from google.ads.google_ads.v1.proto.services.keyword_plan_ad_group_service_pb2 import MutateKeywordPlanAdGroupsResponse as MutateKeywordPlanAdGroupsResponse
from google.ads.google_ads.v1.proto.services.keyword_plan_campaign_service_pb2 import GetKeywordPlanCampaignRequest as GetKeywordPlanCampaignRequest
from google.ads.google_ads.v1.proto.services.keyword_plan_campaign_service_pb2 import KeywordPlanCampaignOperation as KeywordPlanCampaignOperation
from google.ads.google_ads.v1.proto.services.keyword_plan_campaign_service_pb2 import MutateKeywordPlanCampaignResult as MutateKeywordPlanCampaignResult
from google.ads.google_ads.v1.proto.services.keyword_plan_campaign_service_pb2 import MutateKeywordPlanCampaignsRequest as MutateKeywordPlanCampaignsRequest
from google.ads.google_ads.v1.proto.services.keyword_plan_campaign_service_pb2 import MutateKeywordPlanCampaignsResponse as MutateKeywordPlanCampaignsResponse
from google.ads.google_ads.v1.proto.services.keyword_plan_idea_service_pb2 import GenerateKeywordIdeaResponse as GenerateKeywordIdeaResponse
from google.ads.google_ads.v1.proto.services.keyword_plan_idea_service_pb2 import GenerateKeywordIdeaResult as GenerateKeywordIdeaResult
from google.ads.google_ads.v1.proto.services.keyword_plan_idea_service_pb2 import GenerateKeywordIdeasRequest as GenerateKeywordIdeasRequest
from google.ads.google_ads.v1.proto.services.keyword_plan_idea_service_pb2 import KeywordAndUrlSeed as KeywordAndUrlSeed
from google.ads.google_ads.v1.proto.services.keyword_plan_idea_service_pb2 import KeywordSeed as KeywordSeed
from google.ads.google_ads.v1.proto.services.keyword_plan_idea_service_pb2 import UrlSeed as UrlSeed
from google.ads.google_ads.v1.proto.services.keyword_plan_keyword_service_pb2 import GetKeywordPlanKeywordRequest as GetKeywordPlanKeywordRequest
from google.ads.google_ads.v1.proto.services.keyword_plan_keyword_service_pb2 import KeywordPlanKeywordOperation as KeywordPlanKeywordOperation
from google.ads.google_ads.v1.proto.services.keyword_plan_keyword_service_pb2 import MutateKeywordPlanKeywordResult as MutateKeywordPlanKeywordResult
from google.ads.google_ads.v1.proto.services.keyword_plan_keyword_service_pb2 import MutateKeywordPlanKeywordsRequest as MutateKeywordPlanKeywordsRequest
from google.ads.google_ads.v1.proto.services.keyword_plan_keyword_service_pb2 import MutateKeywordPlanKeywordsResponse as MutateKeywordPlanKeywordsResponse
from google.ads.google_ads.v1.proto.services.keyword_plan_negative_keyword_service_pb2 import GetKeywordPlanNegativeKeywordRequest as GetKeywordPlanNegativeKeywordRequest
from google.ads.google_ads.v1.proto.services.keyword_plan_negative_keyword_service_pb2 import KeywordPlanNegativeKeywordOperation as KeywordPlanNegativeKeywordOperation
from google.ads.google_ads.v1.proto.services.keyword_plan_negative_keyword_service_pb2 import MutateKeywordPlanNegativeKeywordResult as MutateKeywordPlanNegativeKeywordResult
from google.ads.google_ads.v1.proto.services.keyword_plan_negative_keyword_service_pb2 import MutateKeywordPlanNegativeKeywordsRequest as MutateKeywordPlanNegativeKeywordsRequest
from google.ads.google_ads.v1.proto.services.keyword_plan_negative_keyword_service_pb2 import MutateKeywordPlanNegativeKeywordsResponse as MutateKeywordPlanNegativeKeywordsResponse
from google.ads.google_ads.v1.proto.services.keyword_plan_service_pb2 import ForecastMetrics as ForecastMetrics
from google.ads.google_ads.v1.proto.services.keyword_plan_service_pb2 import GenerateForecastMetricsRequest as GenerateForecastMetricsRequest
from google.ads.google_ads.v1.proto.services.keyword_plan_service_pb2 import GenerateForecastMetricsResponse as GenerateForecastMetricsResponse
from google.ads.google_ads.v1.proto.services.keyword_plan_service_pb2 import GenerateHistoricalMetricsRequest as GenerateHistoricalMetricsRequest
from google.ads.google_ads.v1.proto.services.keyword_plan_service_pb2 import GenerateHistoricalMetricsResponse as GenerateHistoricalMetricsResponse
from google.ads.google_ads.v1.proto.services.keyword_plan_service_pb2 import GetKeywordPlanRequest as GetKeywordPlanRequest
from google.ads.google_ads.v1.proto.services.keyword_plan_service_pb2 import KeywordPlanAdGroupForecast as KeywordPlanAdGroupForecast
from google.ads.google_ads.v1.proto.services.keyword_plan_service_pb2 import KeywordPlanCampaignForecast as KeywordPlanCampaignForecast
from google.ads.google_ads.v1.proto.services.keyword_plan_service_pb2 import KeywordPlanKeywordForecast as KeywordPlanKeywordForecast
from google.ads.google_ads.v1.proto.services.keyword_plan_service_pb2 import KeywordPlanKeywordHistoricalMetrics as KeywordPlanKeywordHistoricalMetrics
from google.ads.google_ads.v1.proto.services.keyword_plan_service_pb2 import KeywordPlanOperation as KeywordPlanOperation
from google.ads.google_ads.v1.proto.services.keyword_plan_service_pb2 import MutateKeywordPlansRequest as MutateKeywordPlansRequest
from google.ads.google_ads.v1.proto.services.keyword_plan_service_pb2 import MutateKeywordPlansResponse as MutateKeywordPlansResponse
from google.ads.google_ads.v1.proto.services.keyword_plan_service_pb2 import MutateKeywordPlansResult as MutateKeywordPlansResult
from google.ads.google_ads.v1.proto.services.keyword_view_service_pb2 import GetKeywordViewRequest as GetKeywordViewRequest
from google.ads.google_ads.v1.proto.services.label_service_pb2 import GetLabelRequest as GetLabelRequest
from google.ads.google_ads.v1.proto.services.label_service_pb2 import LabelOperation as LabelOperation
from google.ads.google_ads.v1.proto.services.label_service_pb2 import MutateLabelResult as MutateLabelResult
from google.ads.google_ads.v1.proto.services.label_service_pb2 import MutateLabelsRequest as MutateLabelsRequest
from google.ads.google_ads.v1.proto.services.label_service_pb2 import MutateLabelsResponse as MutateLabelsResponse
from google.ads.google_ads.v1.proto.services.landing_page_view_service_pb2 import GetLandingPageViewRequest as GetLandingPageViewRequest
from google.ads.google_ads.v1.proto.services.language_constant_service_pb2 import GetLanguageConstantRequest as GetLanguageConstantRequest
from google.ads.google_ads.v1.proto.services.location_view_service_pb2 import GetLocationViewRequest as GetLocationViewRequest
from google.ads.google_ads.v1.proto.services.managed_placement_view_service_pb2 import GetManagedPlacementViewRequest as GetManagedPlacementViewRequest
from google.ads.google_ads.v1.proto.services.media_file_service_pb2 import GetMediaFileRequest as GetMediaFileRequest
from google.ads.google_ads.v1.proto.services.media_file_service_pb2 import MediaFileOperation as MediaFileOperation
from google.ads.google_ads.v1.proto.services.media_file_service_pb2 import MutateMediaFileResult as MutateMediaFileResult
from google.ads.google_ads.v1.proto.services.media_file_service_pb2 import MutateMediaFilesRequest as MutateMediaFilesRequest
from google.ads.google_ads.v1.proto.services.media_file_service_pb2 import MutateMediaFilesResponse as MutateMediaFilesResponse
from google.ads.google_ads.v1.proto.services.merchant_center_link_service_pb2 import GetMerchantCenterLinkRequest as GetMerchantCenterLinkRequest
from google.ads.google_ads.v1.proto.services.merchant_center_link_service_pb2 import ListMerchantCenterLinksRequest as ListMerchantCenterLinksRequest
from google.ads.google_ads.v1.proto.services.merchant_center_link_service_pb2 import ListMerchantCenterLinksResponse as ListMerchantCenterLinksResponse
from google.ads.google_ads.v1.proto.services.merchant_center_link_service_pb2 import MerchantCenterLinkOperation as MerchantCenterLinkOperation
from google.ads.google_ads.v1.proto.services.merchant_center_link_service_pb2 import MutateMerchantCenterLinkRequest as MutateMerchantCenterLinkRequest
from google.ads.google_ads.v1.proto.services.merchant_center_link_service_pb2 import MutateMerchantCenterLinkResponse as MutateMerchantCenterLinkResponse
from google.ads.google_ads.v1.proto.services.merchant_center_link_service_pb2 import MutateMerchantCenterLinkResult as MutateMerchantCenterLinkResult
from google.ads.google_ads.v1.proto.services.mobile_app_category_constant_service_pb2 import GetMobileAppCategoryConstantRequest as GetMobileAppCategoryConstantRequest
from google.ads.google_ads.v1.proto.services.mobile_device_constant_service_pb2 import GetMobileDeviceConstantRequest as GetMobileDeviceConstantRequest
from google.ads.google_ads.v1.proto.services.mutate_job_service_pb2 import AddMutateJobOperationsRequest as AddMutateJobOperationsRequest
from google.ads.google_ads.v1.proto.services.mutate_job_service_pb2 import AddMutateJobOperationsResponse as AddMutateJobOperationsResponse
from google.ads.google_ads.v1.proto.services.mutate_job_service_pb2 import CreateMutateJobRequest as CreateMutateJobRequest
from google.ads.google_ads.v1.proto.services.mutate_job_service_pb2 import CreateMutateJobResponse as CreateMutateJobResponse
from google.ads.google_ads.v1.proto.services.mutate_job_service_pb2 import GetMutateJobRequest as GetMutateJobRequest
from google.ads.google_ads.v1.proto.services.mutate_job_service_pb2 import ListMutateJobResultsRequest as ListMutateJobResultsRequest
from google.ads.google_ads.v1.proto.services.mutate_job_service_pb2 import ListMutateJobResultsResponse as ListMutateJobResultsResponse
from google.ads.google_ads.v1.proto.services.mutate_job_service_pb2 import MutateJobResult as MutateJobResult
from google.ads.google_ads.v1.proto.services.mutate_job_service_pb2 import RunMutateJobRequest as RunMutateJobRequest
from google.ads.google_ads.v1.proto.services.operating_system_version_constant_service_pb2 import GetOperatingSystemVersionConstantRequest as GetOperatingSystemVersionConstantRequest
from google.ads.google_ads.v1.proto.services.paid_organic_search_term_view_service_pb2 import GetPaidOrganicSearchTermViewRequest as GetPaidOrganicSearchTermViewRequest
from google.ads.google_ads.v1.proto.services.parental_status_view_service_pb2 import GetParentalStatusViewRequest as GetParentalStatusViewRequest
from google.ads.google_ads.v1.proto.services.payments_account_service_pb2 import ListPaymentsAccountsRequest as ListPaymentsAccountsRequest
from google.ads.google_ads.v1.proto.services.payments_account_service_pb2 import ListPaymentsAccountsResponse as ListPaymentsAccountsResponse
from google.ads.google_ads.v1.proto.services.product_bidding_category_constant_service_pb2 import GetProductBiddingCategoryConstantRequest as GetProductBiddingCategoryConstantRequest
from google.ads.google_ads.v1.proto.services.product_group_view_service_pb2 import GetProductGroupViewRequest as GetProductGroupViewRequest
from google.ads.google_ads.v1.proto.services.recommendation_service_pb2 import ApplyRecommendationOperation as ApplyRecommendationOperation
from google.ads.google_ads.v1.proto.services.recommendation_service_pb2 import ApplyRecommendationRequest as ApplyRecommendationRequest
from google.ads.google_ads.v1.proto.services.recommendation_service_pb2 import ApplyRecommendationResponse as ApplyRecommendationResponse
from google.ads.google_ads.v1.proto.services.recommendation_service_pb2 import ApplyRecommendationResult as ApplyRecommendationResult
from google.ads.google_ads.v1.proto.services.recommendation_service_pb2 import DismissRecommendationRequest as DismissRecommendationRequest
from google.ads.google_ads.v1.proto.services.recommendation_service_pb2 import DismissRecommendationResponse as DismissRecommendationResponse
from google.ads.google_ads.v1.proto.services.recommendation_service_pb2 import GetRecommendationRequest as GetRecommendationRequest
from google.ads.google_ads.v1.proto.services.remarketing_action_service_pb2 import GetRemarketingActionRequest as GetRemarketingActionRequest
from google.ads.google_ads.v1.proto.services.remarketing_action_service_pb2 import MutateRemarketingActionResult as MutateRemarketingActionResult
from google.ads.google_ads.v1.proto.services.remarketing_action_service_pb2 import MutateRemarketingActionsRequest as MutateRemarketingActionsRequest
from google.ads.google_ads.v1.proto.services.remarketing_action_service_pb2 import MutateRemarketingActionsResponse as MutateRemarketingActionsResponse
from google.ads.google_ads.v1.proto.services.remarketing_action_service_pb2 import RemarketingActionOperation as RemarketingActionOperation
from google.ads.google_ads.v1.proto.services.search_term_view_service_pb2 import GetSearchTermViewRequest as GetSearchTermViewRequest
from google.ads.google_ads.v1.proto.services.shared_criterion_service_pb2 import GetSharedCriterionRequest as GetSharedCriterionRequest
from google.ads.google_ads.v1.proto.services.shared_criterion_service_pb2 import MutateSharedCriteriaRequest as MutateSharedCriteriaRequest
from google.ads.google_ads.v1.proto.services.shared_criterion_service_pb2 import MutateSharedCriteriaResponse as MutateSharedCriteriaResponse
from google.ads.google_ads.v1.proto.services.shared_criterion_service_pb2 import MutateSharedCriterionResult as MutateSharedCriterionResult
from google.ads.google_ads.v1.proto.services.shared_criterion_service_pb2 import SharedCriterionOperation as SharedCriterionOperation
from google.ads.google_ads.v1.proto.services.shared_set_service_pb2 import GetSharedSetRequest as GetSharedSetRequest
from google.ads.google_ads.v1.proto.services.shared_set_service_pb2 import MutateSharedSetResult as MutateSharedSetResult
from google.ads.google_ads.v1.proto.services.shared_set_service_pb2 import MutateSharedSetsRequest as MutateSharedSetsRequest
from google.ads.google_ads.v1.proto.services.shared_set_service_pb2 import MutateSharedSetsResponse as MutateSharedSetsResponse
from google.ads.google_ads.v1.proto.services.shared_set_service_pb2 import SharedSetOperation as SharedSetOperation
from google.ads.google_ads.v1.proto.services.shopping_performance_view_service_pb2 import GetShoppingPerformanceViewRequest as GetShoppingPerformanceViewRequest
from google.ads.google_ads.v1.proto.services.topic_constant_service_pb2 import GetTopicConstantRequest as GetTopicConstantRequest
from google.ads.google_ads.v1.proto.services.topic_view_service_pb2 import GetTopicViewRequest as GetTopicViewRequest
from google.ads.google_ads.v1.proto.services.user_interest_service_pb2 import GetUserInterestRequest as GetUserInterestRequest
from google.ads.google_ads.v1.proto.services.user_list_service_pb2 import GetUserListRequest as GetUserListRequest
from google.ads.google_ads.v1.proto.services.user_list_service_pb2 import MutateUserListResult as MutateUserListResult
from google.ads.google_ads.v1.proto.services.user_list_service_pb2 import MutateUserListsRequest as MutateUserListsRequest
from google.ads.google_ads.v1.proto.services.user_list_service_pb2 import MutateUserListsResponse as MutateUserListsResponse
from google.ads.google_ads.v1.proto.services.user_list_service_pb2 import UserListOperation as UserListOperation
from google.ads.google_ads.v1.proto.services.video_service_pb2 import GetVideoRequest as GetVideoRequest
